#R codes for Parodi et al. 2020, Journal of Cleaner Production:
#Bioconversion efficiencies, greenhouse gas and ammonia emissions during black soldier fly rearing  a mass balance approach. 

#Structure:

#1. Import data and modify datasets for input and output of nutrient balance
 #1.1 Fresh biomass (diet, starters, yields of larvae and residues)
 #1.2 Nutrient composition parts (result chemical analysis)
 #1.3 Merge fresh biomass and nutrient composition - Mass flow table with nutrient inputs and outputs
 #1.3 Acid and condensed water
 #1.4 Gasses (CO2, CH4) and energy lost as heat 
 #1.5 Table 1
 #1.6 Table S1

#2. Nutrient balances 
 #2.1 Inputs
 #2.2 Outputs
 #2.3 Correction to sum 100% and add Average value for each nutrient
 #2.4 Exploratory figure with outputs
 #2.5 Creation of dataframe for Sankey diagrams per nutrient 
 #2.6 Sankey Diagrams


#3.  GHG and Ammonia emissions
#3.1 Nitrous oxide
 #3.1.1 Estimate total ventilated day per N2O day
 #3.1.2 Add N2O concentration and estimate overall N2O per replicate
 #3.1.3. Create dataframes for figure and plot figures

#3.2 Ammonia
 #3.2.1 Prepare dataset for figures
 #3.2.2 Ammonia Figures
#3.3 Overall GHG emissions (N2O, CO2, CH4) and total Nitrogen
 #3.3.1 overall GHG emissions per replicate
 #3.3.2 fresh and dry larvae yield per replicate 
 #3.3.3 Both dataframes are combined to estimate the emissions per kg of dry larvae (Table 2)
 #3.3.4 There is an additional calculation for methane in which some outliers were removed

#4. Figures 3 and Figure S3

#5. Analysis for Supplementary Figures
 #5.1 Starch in residues (Figure S1)
 #5.2 Recalculation of efficiencies with corrected starch
 #5.3 Microbial emissions - Figure S2
 #5.4 Correlation CO2 and NH4 (Figure S4) and regression (Table S2)
 #5.5 Parameters (larvae, water, residues, size, etc)
  #5.5.1 Average size of starters and 14-days old larvae
  #5.5.2 Material degradation
  #5.5.3 Water balance
  #5.5.4 Formatting for Suplementary Table S4




#Important message
#Most input datasets contain data for all experimental replicates.
#Experimental replicates start with "Replicate1" and finish with "Replicate20".
#Not all the replicates were used for this study (some of them had a different density of larvae per unit of diet, and other experienced technical
#problems during the experiments). Therefore for this study we only present the data for 11 replicates, which are:
#Replicate8, Replicate9, Replicate10, Replicate11, Replicate12, Replicate13, Replicate14, Replicate15, Replicate16, Replicate19 and Replicate20.
#All analysis were done with these replicates names, however, for final graphs and tables, replicates were re-labeled in the following way:
#Replicate 8 -> Replicate 1
#Replicate 9 -> Replicate 2
#Replicate 10 -> Replicate 3
#Replicate 11 -> Replicate 4
#Replicate 12 -> Replicate 5
#Replicate 13 -> Replicate 6
#Replicate 14 -> Replicate 7
#Replicate 15 -> Replicate 8
#Replicate 16 -> Replicate 9
#Replicate 19 -> Replicate 10
#Replicate 20 -> Replicate 11

#Packages required to run this script:
library(magrittr)
library(dplyr)
library(tidyr)
library(plyr)
library(chron)
library(ggplot2)
library(scales)
library(gridExtra)
library(plotrix)
library(reshape2)
library(networkD3)
library(webshot)    #webshot::install_phantomjs() #to convert sankey diagram to pdf
library(pragma)
library(imputeTS)
library(broom)
library(ggpubr)
library(dlookr) 

#Set working directory
setwd("write working directory path")
getwd()


#1.1. Fresh biomass
#It contains the grams of starter larvae, grams of diet, grams of mature larvae harvested, grams of frass and grams of crust.
#For replicates 8:12, there is no "crust" value because this was not separated from the frass (everything was weighted together).

#Import dataset
fresh_biomass <- read.csv("fresh_biomass.csv")
#Explanation columns
#[1] "replicate" - Replicate number
#[2] "crate position" - Every replicate had three crate stack one in top of the other : Bottom, Medium, Top.
#[3] "starter" - grams of starters that made 10 000 starters (values vary because starts didn't have the same weight in all batches)
#[4] "diet" - grams of substrate supplied per crate
#[5] "larvae" - larvae yield in grams per crate at the end of the experimental replicate
#[6] "frass" - grams of frass per crate at the end of the experimental replicate
#[7] "crust" - grams of crust per crate at the end of the experimental replicate


#Reorganize dataset
fresh_biomass <- gather(fresh_biomass, "part", "fresh_grams", 3:7)

#Sum the values of the 3 crates that make one replicate
#this could be a supplementary table (if needed)
fresh_biomass_replicate <- ddply(fresh_biomass, .(replicate, part), summarize, 
                                 freshweight_grams = sum(fresh_grams, na.rm=TRUE))

#Create a concatenate column to merge it with the other dataset
fresh_biomass_replicate$concatenate <- with(fresh_biomass_replicate, paste0(replicate, "_", part))






#1.2. Nutrient composition parts
#Import dataset of nutritional results

nutritional_results <- read.csv("nutritional_results.csv")
#Explanation columns
#[1] "replicate" - Replicate number
#[2] "part" - Type of sample: diet, starter, frass, crust, larvae
#[3] "DM" - Proportion of dry matter
#[4] "N" - Nitrogen content in g/kg dry matter
#[5] "C" - Carbon content in g/kg dry matter
#[6] "E" - Energy content in KJ/kg dry matter
#[7] "K" - Potassium content in g/kg dry matter
#[8] "P" - Phosphorus content in g/kg dry matter
#[9] "CFAT" - Crude fat content in g/kg dry matter
#[10] "STARCH" - Starch content in g/kg dry matter


#Create a concatenate column to merge it with the other dataset
nutritional_results$concatenate <- with(nutritional_results, paste0(replicate, "_", part))





#1.3 Merge fresh biomass and nutrient composition and get a mass flow table with all nutrient inputs and outputs
#Merge datasets fresh biomass with nutritional results:
nutrient_balance <- merge(fresh_biomass_replicate, nutritional_results, by="concatenate", all=T)
#Remove unnecessary columns
nutrient_balance <- nutrient_balance [, -(5:6), drop=FALSE]

#create new column for dryweight values
nutrient_balance$dryweight_grams <- nutrient_balance$freshweight_grams*nutrient_balance$DM 

#create new columns for the overall content of each nutrient (in grams)
nutrient_balance$N_overall <- (nutrient_balance$dryweight_grams*nutrient_balance$N)/1000
nutrient_balance$C_overall <- (nutrient_balance$dryweight_grams*nutrient_balance$C)/1000
nutrient_balance$E_overall <- (nutrient_balance$dryweight_grams*nutrient_balance$E)/1000
nutrient_balance$K_overall <- (nutrient_balance$dryweight_grams*nutrient_balance$K)/1000
nutrient_balance$P_overall <- (nutrient_balance$dryweight_grams*nutrient_balance$P)/1000
nutrient_balance$CFAT_overall <- (nutrient_balance$dryweight_grams*nutrient_balance$CFAT)/1000
nutrient_balance$STARCH_overall <- (nutrient_balance$dryweight_grams*nutrient_balance$STARCH)/1000


#The idea is to create a new dataset in which frass and crust nutrients are sum into the category "Residual_substrate".
#For that, first a new dataset (nutrient_balance2) with the overall nutrient content in starter, larvae (mature) and  diet will be created
#To this dataset, new rows will be added under the part name "Residual_substrate" which is the sum of frass and crust (for those which had 2 fractions)

#Dataset with starter, larvae (mature) and diet
nutrient_balance2 <- subset(nutrient_balance, (part.x!= "frass" & part.x!= "crust"))
nutrient_balance2 <- nutrient_balance2 [, -(4:12), drop=FALSE]
nutrient_balance2 <- nutrient_balance2 [, -1]

#Steps to calculate get the sum of frass and crust, and create the category residual substrate
join_frass_crust <- subset(nutrient_balance, (part.x== "frass" | part.x== "crust"))
join_frass_crust <- join_frass_crust [, -(4:12), drop=FALSE]
join_frass_crust2<- ddply(join_frass_crust, .(replicate.x), summarize, 
                          DM_overall = sum(dryweight_grams, na.rm=TRUE),
                          N_overall = sum(N_overall, na.rm=TRUE),
                          C_overall = sum(C_overall, na.rm=TRUE),
                          E_overall = sum(E_overall, na.rm=TRUE),
                          P_overall = sum(P_overall, na.rm=TRUE),
                          K_overall = sum(K_overall, na.rm=TRUE),
                          CFAT_overall = sum(CFAT_overall, na.rm = TRUE),
                          STARCH_overall= sum(STARCH_overall, na.rm = TRUE))
join_frass_crust2$part.x <- "Residual_substrate"

#Change column name
names(join_frass_crust2)[2] <- "dryweight_grams"

#reorganize columns
join_frass_crust2 <- join_frass_crust2[,c(1, 10, 2, 3, 4, 5, 6, 7, 8, 9)]

#Bind the two datasets (nutrient_balance 2 with join_frass_crust2) to get the table with the mass flow
nutritional_overall <- rbind(nutrient_balance2, join_frass_crust2)

#In this section, the dataset nutritional_overall is cleaned and organized (new columns, variables are renamed, etc).
nutritional_overall$part.x <- ifelse(nutritional_overall$part.x=="diet", "Diet",
                                     ifelse(nutritional_overall$part.x=="starter", "Starter_larvae", 
                                            ifelse(nutritional_overall$part.x=="larvae", "Larvae", "Residual_substrate")))
#Create copy of nutritional_overall because it will be used later for the elaboration of Table 1
Table1 <- nutritional_overall

#Add input/output column
nutritional_overall$general <- ifelse(nutritional_overall$part.x=="Diet" | nutritional_overall$part.x=="Starter_larvae", "Input", "Output")

#Add additional column part2 (for  subsequent analysis)
nutritional_overall$part2 <- nutritional_overall$part.x

#reorder columns
nutritional_overall <- nutritional_overall[, c(1, 11, 2, 12, 3, 4, 5, 6, 7, 8, 9, 10)]
names(nutritional_overall)[1] <- "replicate"

#The dataset nutritional_overall will be called later to add the overall amounts of nitrogen
#found in acid and condensed water and then the overall amounts of air gasses (CO2, CH4).
#With this two additions (Nitrogen in acid and condensed water, and nutrient in gasses) the mass flow table will be ready



#1.3 Acid and condensed water

#import dataset
acid_condensedwater <- read.csv("acid_condensedwater.csv")

#Explanation columns
#[1] "replicate" - Replicate number
#[2] "acid_bottleempty_grams" - Weight in grams of the empty bottle that contained the acid
#[3] "acid_bottle_afterperiod_grams" - Weight of the bottle in grams with acid at the end of the experimental replicate
#[4] "acid_gasmeter_valueupfront_m3" - Start value (m3) of the gasmeter that measured the amount of air that entered the acid bottle at the start of the experimental replicate
#[5] "acid_gasmeter_valueafterperiod_m3" - Final value (m3) of the gasmeter that measured the amount of air that entered the acid bottle at the end of the experimental replicate
#[6] "overal_air_flowm3"- Total air flow (m3) in the chamber during a experimental replicate
#[7] "N_acid_units" - Grams of Nitrogen in 1kg  of acid
#[8] "tare_bucket" - Weight in grams of the empty bucket that collected the condensed water
#[9] "cw_gross_grams" - Weight of the bucket plus the condensed water collected at the end of the experimental replicate
#[10] "N_condensedwater_units" - Grams of Nitrogen in 1 kg of condensed water

#separate datasets, one for acid and another for condensed water
acid <- acid_condensedwater %>% select(1:7)
condensewater <- acid_condensedwater %>% select(1, 8, 9, 10)

# Acid
#calculate net weight values of acid (grams) and total gas flow
acid$netbottle_grams <- acid$acid_bottle_afterperiod_grams - acid$acid_bottleempty_grams

#calculate the flow (m3) of air through the gasflowmeters of the washing bottle
acid$net_air_flowm3 <- acid$acid_gasmeter_valueafterperiod_m3 - acid$acid_gasmeter_valueupfront_m3

#calculate the total amount of N in each acid sample
acid$N_sample_grams <- (acid$N_acid_units*acid$netbottle_grams)/1000

#Calculate the total grams of N in the whole period (equation 3 of the paper)
acid$N_overall <- acid$N_acid_units/1000 * (acid$overal_air_flowm3*acid$netbottle_grams/acid$net_air_flowm3)
acid$C_overall <- 0
acid$E_overall <- 0
acid$K_overall <- 0
acid$P_overall <- 0
acid$CFAT_overall <- 0
acid$STARCH_overall <- 0

#Reorder dataset to bind it to nutritional_overall
acid2 <- acid %>% select(1, 11, 12, 13, 14, 15, 16, 17)
acid2$general <- "Output"
acid2$part.x <- "Air"
acid2$part2 <- "Acid"
acid2$dryweight_grams <- NA
acid2 <- acid2[, c(1, 9, 10, 11, 12, 2, 3, 4, 5, 6, 7, 8)]


#Condensed water

#add column with net condensed water
condensewater$cw_net_grams <- condensewater$cw_gross_grams - condensewater$tare_bucket
condensewater$N_overall <- (condensewater$cw_net_grams * condensewater$N_condensedwater_units)/1000
condensewater$C_overall <- 0
condensewater$E_overall <- 0
condensewater$K_overall <- 0
condensewater$P_overall <- 0
condensewater$CFAT_overall <- 0
condensewater$STARCH_overall <- 0

#format dataset as acid2
cw <- condensewater %>% select (1, 6, 7, 8, 9, 10, 11, 12)
cw$general <- "Output"
cw$part.x <- "Air"
cw$part2 <- "Condensed water"
cw$dryweight_grams <- NA
cw <- cw[, c(1, 9, 10, 11, 12, 2, 3, 4, 5, 6, 7, 8)]

#newdataset for total N emissions (sum acid and condensed water)
total_cw <- cw %>% select(1,6)
total_acid <- acid2 %>% select(1, 6)
total_n <- merge(total_cw, total_acid, by="replicate")
total_n$sum <- total_n$N_overall.x + total_n$N_overall.y
total_n <- total_n %>% select(1,4)
names(total_n)[2] <- "N (g)"


#Add cw and acid to nutritional overall
nutritional_overall <- rbind(nutritional_overall, acid2, cw) 





#1.4 Gasses (CO2, CH4)
#In this section the grams of C contained in CO2 and CH4, and the Energy released as heat will be added to the dataframe nutritional overall. With this addition
#the mass flow table is ready

#Import gas dataset for CO2, O2 and CH4
gas_co2_o2_ch4 <- read.csv("gas_co2_o2_ch4.csv")

#Explanation columns
#[1] "X" - Autonumeric (not used in the analysis)
#[2] "cel" - Refers to the respiration chamber in which the data was measured. In the experiments there were two climate respiration chambers: number 5 and number 6.
#[3] "B" - ID number of an experiment running simultaneously in two chambers. For example, replicates 9 and 10 were done simultaneously, one in chamber 5 and the other in chamber 6. Therefore, the B number is the same for both replicates.
#[4] "C" - Technical parameter of the climate respiration chamber (not used in the analysis)
#[5] "date" - Date in which the gas measurement took place.
#[6] "time" - Time in which the gas measurement took place.
#[7] "F" - Technical parameter of the climate respiration chamber (not used in the analysis)
#[8] "Heat" - Metabolic heat calculated by indirect calorimetry (KJ/Day)
#[9] "O2" - Oxigen consumption (L/day)
#[10] "CO2" - Carbon dioxide production (L/day)
#[11] "RQ" - Respiratory quotient (obtained by dividing CO2/O2)
#[12] "K" - Technical parameter of the climate respiration chamber (not used in the analysis)
#[13] "L" - Technical parameter of the climate respiration chamber (not used in the analysis)
#[14] "M" - Technical parameter of the climate respiration chamber (not used in the analysis)
#[15] "Barometric_pressure(mmHg)" - 	Barometric_pressure inside the chamber
#[16] "Temperature"	 - Temperature inside the chamber
#[17] "Humidity" - 	Humidity inside the chamber
#[18] "STDP" - 	Air ventilation (L/min) at standard pressure and temperature.
#[19] "CH4" - 	methane (L/day)
#[20] "Volume_corrected" - 	Volume of the chamber (L) corrected for pressure and temperature.
#[21] "day" - Obtained from the column "date". Shows the day number of the measurement (for example if date is 28/07/2018, day would be 28)
#[22] "month" - Obtained from the column "date". Shows the month number of the measurement (from 1 to 12)
#[23] "year" - 	Obtained from the column "date". Shows the year number of the measurement
#[24] "hour" - 	Obtained from the column "time". Shows the hour of day in 24:00 format in which the measurement was taken
#[25] "minute" - Obtained from the column "time". Shows the minutes of the hour in which the measurement was taken
#[26] "second"- Obtained from the column "time". Shows the seconds of the minute in which the measurement was taken	
#[27] "replicate" - Replicate ID.
#[28] "daynumber" - Number of day for each replicate (goes from Day 1 to Day 8). This was created for the Figures (days go from 00:00 to 00:00) and used for the analysis
#[29] "daynumbern2o" - Another clasification of the day number which was made only to quantify the N2O levels (days go from 12:00 to 12:00)

# A new column is added to get the ventilation in wet air (without correction for pressure and temperature as shown in column [18])
# The new ventilation in wet air is needed to estimate estimate N2O emissions given that N2O concentrations were measured in wet air (see equation 4 in paper)
# To calculate the ventilation in wet air we need to estimate the water pressure:
gas_co2_o2_ch4$PH20 <- (gas_co2_o2_ch4$Humidity*(3.999+0.455417*(gas_co2_o2_ch4$Temperature)+0.001708*(gas_co2_o2_ch4$Temperature^2) +0.000468*(gas_co2_o2_ch4$Temperature^3)))/100  

#Calculate ventilation (column 30)
gas_co2_o2_ch4$ventilation <- (gas_co2_o2_ch4$STDP/(gas_co2_o2_ch4$Barometric_preassure.mmHg. - gas_co2_o2_ch4$PH20)) * 760 * (273.15 + gas_co2_o2_ch4$Temperature) / 273.15
gas_co2_o2_ch4$PH20 <- NULL



# Now, with the complete dataset, we estimate grams of carbon lost as methane and carbon dioxide. Some of the dataframes created in these steps
# will be used in later sections to estimate the overall GHG emissions of CO2 and CH4.

#Summarize data to obtain average values per hour
chambers_summary2 <- ddply(gas_co2_o2_ch4, .(replicate, daynumber, hour), summarize, 
                           mean_CO2= mean(CO2, na.rm=TRUE), 
                           stdev_CO2= sd(CO2, na.rm=TRUE),
                           mean_CH4= mean(CH4, na.rm=TRUE), 
                           stdev_CH4= sd(CH4, na.rm=TRUE),
                           mean_O2=mean(O2, na.rm=TRUE),
                           stdev_O2=sd(O2, na.rm=TRUE),
                           mean_heat= mean(Heat, na.rm=TRUE), 
                           stdev_heat= sd(Heat, na.rm=TRUE),
                           mean_temp= mean(Temperature, na.rm=TRUE), 
                           stdev_temp= sd(Temperature, na.rm=TRUE),
                           mean_RQ= mean(RQ, na.rm=TRUE), 
                           stdev_RQ= sd(RQ, na.rm=TRUE),
                           mean_STDP= mean(STDP, na.rm=TRUE),
                           mean_ventilation = mean(ventilation, na.rm=TRUE))



# Changing the units of  CO2, CH4 from L/day to g/per hour
#For that, we need the following information: 
#1. molar masses of C, H, O, N atoms:
#carbon 12 g
#hydrogen 1.008 g
#Oxygen 16 g
#nitrogen 14.01 g

#2. grams of each atom per 1 mol.
#number of liters of any gas in one mol = 22.4 l/mol
#molar mass CO2 = Carbon is 12, Oxygen is 16 = 12 x 2(16) = 44.01 g/mol
#molar mass CH4 = 16.04 g/mol
#molar mass NH3 = 17.031 g/mol
#molar mass N2O = 44.02 g/mol


#3. Conversion factors to convert from liters to grams (molar mass/22.4)
#CO2 ---> 44.01/22.4 = 1.964732
#CH4 ---> 16.06/22.4 = 0.7169643
#NH3 ---> 17.031/22.4 = 0.7603125
#O2 ----> 32/22.4 = 1.428571
#N2O ---> 44.02/22.4 =  1.965179

#Use the conversion factor from liters to grams and divide the result by 24 to have grams produced per hour
#This table show the total grams of CO2, CH4 and Energy per hour per day
chambers_summary2$weight_co2_grams <-(chambers_summary2$mean_CO2 * 1.964732)/24
chambers_summary2$weight_ch4_grams <-(chambers_summary2$mean_CH4 * 0.7169643)/24
chambers_summary2$kj <-(chambers_summary2$mean_heat)/24 #units KJ/hour

#This table show the total grams of CO2, CH4 and Energy per replicate (all days and hours summed)
gasses_weight <- ddply(chambers_summary2, .(replicate), summarize, 
                       total_co2_grams = sum(weight_co2_grams),
                       total_ch4_grams = sum(weight_ch4_grams),
                       totalE = sum(kj))


#Calculate the total amount of C lost as CO2 and CH4 (in grams). 
#This will be used for the C balance
#To know the proportion of C in CO2, the molar mass of Carbon has to be divided by the molar mass of carbon dioxide. 12/44 = 0.272727
#For methane, 12/16.04 = 0.747198

gasses_weight$totalC <- (gasses_weight$total_co2_grams*0.27272727) + (gasses_weight$total_ch4_grams*0.747198)

#newdataset with format to merge it with nutritional overall
co2ch4 <- gasses_weight
co2ch4 <- co2ch4 %>% select (1, 5, 4)
co2ch4$general <- "Output"
co2ch4$part.x <- "Air"
co2ch4$part2 <- "CO2 & CH4"
co2ch4$dryweight_grams <- NA
co2ch4$N_overall <- 0
co2ch4$K_overall <- 0
co2ch4$P_overall <- 0
co2ch4$CFAT_overall <- 0
co2ch4$STARCH_overall <- 0

names(co2ch4)[2] <- "C_overall"
names(co2ch4)[3] <- "E_overall"
co2ch4 <- co2ch4[, c(1, 4, 5, 6, 7, 8, 2, 3, 9, 10, 11, 12)]


#join this with nutritional overall
nutritional_overall <- rbind(nutritional_overall,co2ch4)
#Nutritional overall is complete with all inputs and outputs. This dataset will be used to make Supplementary Table S1
#and the Sankey diagrams with the balances showed in Figure 2.



#1.5 Create Table 1 (nutrient content of parts)

Table1
#Estimate nutrient content per 100grams of dry matter sample for each replicate

Table1$Nitrogen <- (Table1$N_overall * 100)/Table1$dryweight_grams
Table1$Carbon <- (Table1$C_overall * 100)/Table1$dryweight_grams
Table1$Energy <- (Table1$E_overall * 100)/Table1$dryweight_grams
Table1$Phosphorus <- (Table1$P_overall * 100)/Table1$dryweight_grams
Table1$Potassium <- (Table1$K_overall * 100)/Table1$dryweight_grams
Table1$Crude_fat <- (Table1$CFAT_overall * 100)/Table1$dryweight_grams
Table1$Starch <- (Table1$STARCH_overall * 100)/Table1$dryweight_grams

Table1 <- Table1[, -(3:10), drop=FALSE]

Table1 <- gather(Table1, "nutrient", "value", 3:9) 


#Summarize al replicates

Table1_final <- ddply(Table1, .(part.x, nutrient), summarize,
                      mean_value = mean(value),
                      sd_value = sd(value))

Table1_final$value <- with(Table1_final, paste0(round(mean_value, digits = 2), "", round(sd_value, digits = 2))) 

#clean data and organize it to export it in the right format
Table1_final <- Table1_final[, -(3:4), drop=FALSE]
Table1_final <- spread(Table1_final, nutrient, value)
Table1_final <- Table1_final[c(1, 4, 2, 3), ]
Table1_final <- Table1_final[, c(1, 2,4,5,6,7,3,8), ]
names(Table1_final)[1] <- "part.x"
names(Table1_final)[2] <- "Carbon (g)"
names(Table1_final)[3] <- "Energy (KJ)"
names(Table1_final)[4] <- "Total Nitrogen (g)"
names(Table1_final)[5] <- "Phosphorus (g)"
names(Table1_final)[6] <- "Potassium (g)"
names(Table1_final)[7] <- "Crude fat (g)"
names(Table1_final)[8] <- "Starch (g)"


#add dry matter content (%)
dry_matter_parts <- ddply(nutrient_balance, .(part.x), summarize,
                          mean_dm = mean(DM, na.rm = T),
                          sd_dm = sd(DM, na.rm = T))

#Dm content of residual substrate was estimated manually (proportion of frass and crust multiplied by the DM of each, and then summed)
dm_residual <- subset(nutrient_balance, (part.x=="crust" | part.x=="frass"))
dm_residual <- dm_residual %>% select(1, 2, 3, 4, 5)
dm_residual1 <- subset(dm_residual, (!is.na(dm_residual$DM)))
dm_residual1 <- dm_residual %>% select(2,3,4,5)
dm_residual_sum <- ddply(dm_residual1, .(replicate.x), summarize,
                         sum_dm1 = sum(freshweight_grams))

dm_residual1 <- merge(dm_residual1, dm_residual_sum)
dm_residual1$prop <- dm_residual1$freshweight_grams/dm_residual1$sum_dm1
dm_residual1$DM1 <- dm_residual1$DM * dm_residual1$prop
dm_residual2 <- ddply(dm_residual1, .(replicate.x), summarize,
                      drymatter = sum(DM1, na.rm=TRUE))
dm_residues <- ddply(dm_residual2, .(), summarize,
                     mean_dm= mean(drymatter),
                     sd_dm = sd(drymatter))
names(dm_residues)[1] <- "part.x"
dm_residues$part.x <- "Residual_substrate"

dry_matter_parts <- subset(dry_matter_parts, (part.x!= "frass" & part.x!= "crust"))
dry_matter_parts <- rbind(dry_matter_parts, dm_residues)  

dry_matter_parts$part.x <- ifelse(dry_matter_parts$part.x=="diet", "Diet", 
                                  ifelse(dry_matter_parts$part.x=="larvae", "Larvae",
                                         ifelse(dry_matter_parts$part.x=="starter", "Starter_larvae", "Residual_substrate")))

dry_matter_parts$mean_dm <- dry_matter_parts$mean_dm*100
dry_matter_parts$sd_dm <- dry_matter_parts$sd_dm*100
dry_matter_parts$DM <- with(dry_matter_parts, paste0(round(mean_dm, digits = 3), "", round(sd_dm, digits = 2)))
names(dry_matter_parts)[4] <- "DM (%)"
dry_matter_parts <- dry_matter_parts %>% select(1, 4)


#Join table1 final with the dry matter values
Table1_final <- merge(Table1_final, dry_matter_parts)

colnames(Table1_final)[9] <- "Dry matter (%)"
Table1_final <- Table1_final[, c(1, 9, 2, 3, 4, 5, 6, 7, 8)]

#Table 1
Table1_final

#Save table1
#write.csv(Table1_final, file="Table1.csv", row.names=FALSE)





#1.6 Create Supplementary Table S1
TS1 <- nutritional_overall %>% select (1, 2, 4, 5, 6, 7, 8, 9, 10)

names(TS1)[1] <- "Replicate"
names(TS1)[2] <- "Category"
names(TS1)[3] <- "Part"
names(TS1)[4] <- "Dryweight(g)"
names(TS1)[5] <- "N(g)"
names(TS1)[6] <- "C(g)"
names(TS1)[7] <- "E(g)"
names(TS1)[8] <- "K(g)"
names(TS1)[9] <- "P(g)"

#rename replicate numbers
TS1$Replicate <- ifelse(TS1$Replicate=="Replicate8", "R1",
                        ifelse(TS1$Replicate=="Replicate9", "R2",
                               ifelse(TS1$Replicate=="Replicate10", "R3",
                                      ifelse(TS1$Replicate=="Replicate11", "R4",
                                             ifelse(TS1$Replicate=="Replicate12", "R5",
                                                    ifelse(TS1$Replicate=="Replicate13", "R6",
                                                           ifelse(TS1$Replicate=="Replicate14", "R7",
                                                                  ifelse(TS1$Replicate=="Replicate15", "R8",
                                                                         ifelse(TS1$Replicate=="Replicate16", "R9",
                                                                                ifelse(TS1$Replicate=="Replicate19", "R10", "R11"))))))))))

#reorder rows
TS1 <- TS1[order(TS1$Replicate, TS1$Category), ]
TS1
#Save Supplementary Table S1
#write.csv(TS1, file = "TS1.csv", row.names = F)


























#2. Nutrient balances per mass gain

#2.1 Inputs
##### The input is only the diet 
Inputs_diet <- subset(nutritional_overall, (part.x=="Diet"))
Inputs_diet_sum <- ddply(Inputs_diet, .(replicate), summarize, 
                         DM_input = sum(dryweight_grams, na.rm=TRUE),
                         N_input = sum(N_overall, na.rm=TRUE),
                         C_input = sum(C_overall, na.rm=TRUE),
                         E_input = sum(E_overall, na.rm=TRUE),
                         K_input = sum(K_overall, na.rm=TRUE),
                         P_input = sum(P_overall, na.rm=TRUE))





#2.2 Outputs
#This balance is per mass gain. This means, the initial biomass of starters needs to be substracted from the final larvae yield

Nutritional_outputs <- subset(nutritional_overall, (general=="Output"))
Nutritional_outputs2 <- Nutritional_outputs


#Estimate nutrient gains in larvae
Input_starter <- subset(nutritional_overall, (part.x=="Starter_larvae"))
Output_larvae <- subset(Nutritional_outputs2, (part.x == "Larvae"))


Larvae_gain <- merge(Input_starter, Output_larvae, by="replicate", all=T)

Larvae_gain$dryweight_grams <- Larvae_gain$dryweight_grams.y - Larvae_gain$dryweight_grams.x
Larvae_gain$N_gain <- Larvae_gain$N_overall.y - Larvae_gain$N_overall.x
Larvae_gain$C_gain <- Larvae_gain$C_overall.y - Larvae_gain$C_overall.x
Larvae_gain$E_gain <- Larvae_gain$E_overall.y - Larvae_gain$E_overall.x
Larvae_gain$K_gain <- Larvae_gain$K_overall.y - Larvae_gain$K_overall.x
Larvae_gain$P_gain <- Larvae_gain$P_overall.y - Larvae_gain$P_overall.x

#Select desired columns(Nutrient_gains) & edit dataframe it to rbind it with Nutirtional_outputs3
Larvae_gain <- Larvae_gain %>% select (1, 2, 3, 4, 24, 25, 26, 27, 28, 29)
Larvae_gain$part.x.x <- "Larvae_gain"
Larvae_gain$part2.x <- "Larvae_gain"
Larvae_gain$CFAT_overall <- NA
Larvae_gain$STARCH_overall <- NA

names(Larvae_gain)[2] <- "general"
names(Larvae_gain)[3] <- "part.x"
names(Larvae_gain)[4] <- "part2"
names(Larvae_gain)[5] <- "dryweight_grams"
names(Larvae_gain)[6] <- "N_overall"
names(Larvae_gain)[7] <- "C_overall"
names(Larvae_gain)[8] <- "E_overall"
names(Larvae_gain)[9] <- "K_overall"
names(Larvae_gain)[10] <- "P_overall"


#Replace in Nutritional_outputs2, larvae by larvae_gain
Nutritional_outputs3 <- subset(Nutritional_outputs2, (part.x!= "Larvae"))
Nutritional_outputs3 <- rbind(Nutritional_outputs3, Larvae_gain)

#Calculate output percentages based on input
Balance <- merge(Nutritional_outputs3, Inputs_diet, by="replicate", all=T)

Balance$DM_percentage <- Balance$dryweight_grams.x/Balance$dryweight_grams.y
Balance$N_percentage <- Balance$N_overall.x/Balance$N_overall.y*100
Balance$C_percentage <- Balance$C_overall.x/Balance$C_overall.y*100
Balance$E_percentage <- Balance$E_overall.x/Balance$E_overall.y*100
Balance$K_percentage <- Balance$K_overall.x/Balance$K_overall.y*100
Balance$P_percentage <- Balance$P_overall.x/Balance$P_overall.y*100


Balance_graph <- ddply(Balance, .(replicate, part.x.x), summarize,
                       Dry_matter = sum(DM_percentage, na.rm=TRUE),
                       Nitrogen = sum(N_percentage, na.rm=TRUE),
                       Carbon = sum(C_percentage, na.rm=TRUE),
                       Energy = sum(E_percentage, na.rm=TRUE),
                       Phosphorus = sum(P_percentage, na.rm=TRUE),
                       Potassium = sum(K_percentage, na.rm=TRUE)) #everthing is in percentage of total outputs


# Prepare table in which all outputs are summed. These values should be close to 100% as it indicates the sum of outputs equal the input.
sum_balance_graph <- ddply(Balance_graph, .(replicate), summarize,
                           DM_SUM = sum(Dry_matter, na.rm=TRUE),
                           N_SUM = sum(Nitrogen, na.rm=TRUE),
                           C_SUM = sum(Carbon, na.rm=TRUE),
                           E_SUM = sum(Energy, na.rm=TRUE),
                           P_SUM = sum(Phosphorus, na.rm=TRUE),
                           K_SUM = sum(Potassium, na.rm=TRUE))

#The recovery rates are very good, all of them are close to 100%  
#There are small deviations to 100% but these are minor
#It should be noticed that for Dry matter, the sum of outputs does not sum 100% because losses to the air were not accounted in the calculations.

#For dry matter, air losses are estimated based on the difference between input and output (as indicated in figure 2)
#To estimate the outputs for dry matter, this section is needed:

drymatter <- Balance %>% select(1,3,24)
drymatter <- na.omit(drymatter)
drymatter$DM_percentage <- drymatter$DM_percentage*100


drymatter_losses <- sum_balance_graph %>% select (1,2)
drymatter_losses$air_losses <- (1 - drymatter_losses$DM_SUM)*100
drymatter_losses$part.x.x <- "Air"
drymatter_losses$DM_percentage <- drymatter_losses$air_losses
drymatter_losses <- drymatter_losses %>% select(1, 4, 5)


drymatter_total <- rbind(drymatter, drymatter_losses)
names(drymatter_total)[3] <- "DM_corrected"

#2.3 Correction to sum 100% and add Average value for each nutrient

#The following steps will correct the percentage of each parts to sum 100%.
Balance_graph <- merge(Balance_graph, sum_balance_graph, by="replicate")


Balance_graph$N_corrected <- (Balance_graph$Nitrogen*100)/Balance_graph$N_SUM
Balance_graph$C_corrected <- (Balance_graph$Carbon*100)/Balance_graph$C_SUM
Balance_graph$E_corrected <- (Balance_graph$Energy*100)/Balance_graph$E_SUM
Balance_graph$P_corrected <- (Balance_graph$Phosphorus*100)/Balance_graph$P_SUM
Balance_graph$K_corrected <- (Balance_graph$Potassium*100)/Balance_graph$K_SUM


Balance_graph <- Balance_graph %>% select(1, 2, 15, 16, 17, 18, 19)
#This dataframe shows the outputs in percentage in which the sum of all outputs give 100%

#Add dry matter to this table
drymatter_total$concatenate <- paste0(drymatter_total$replicate, "_", drymatter_total$part.x.x)
Balance_graph$concatenate <- paste0(Balance_graph$replicate, "_", Balance_graph$part.x.x)
Balance_graph <- merge(Balance_graph, drymatter_total, by="concatenate")

Balance_graph <- Balance_graph %>% select(2,3,11,4,5,6,7,8)

#Rearrage dataframe to apply facet_wrap and remove 0 values for air in potassium and phosphorus (not measured in air)
Balance_graph <- gather(Balance_graph, "nutrient", "value", 3:8)
Balance_graph$value <-ifelse(Balance_graph$value>0, Balance_graph$value, NA)
Balance_graph <- na.omit(Balance_graph)


#Dataset with corrected output percentages per replicate
Balance_average <- ddply(Balance_graph, .(part.x.x.x, nutrient), summarize,
                         mean = mean(value),
                         sderror = std.error(value),
                         sd = sd(value))



#Add Average file to Balance average
Balance_average$replicate <- "AVG" #this will be used later for a table
Balance_average2 <- Balance_average[, c(6,1,2,3)]
names(Balance_average2)[4] <- "value"
names(Balance_average2)[1] <- "replicate.x"
Balance_graph <- rbind(Balance_graph, Balance_average2)





#2.4 Exploratory figure of outputs

#Create new labels for replicates
Balance_graph$replicate2 <- ifelse(Balance_graph$replicate=="Replicate8", "R1",
                                   ifelse(Balance_graph$replicate=="Replicate9", "R2",
                                          ifelse(Balance_graph$replicate=="Replicate10", "R3",
                                                 ifelse(Balance_graph$replicate=="Replicate11", "R4",
                                                        ifelse(Balance_graph$replicate=="Replicate12", "R5",
                                                               ifelse(Balance_graph$replicate=="Replicate13", "R6",
                                                                      ifelse(Balance_graph$replicate=="Replicate14", "R7",
                                                                             ifelse(Balance_graph$replicate=="Replicate15", "R8",
                                                                                    ifelse(Balance_graph$replicate=="Replicate16", "R9",
                                                                                           ifelse(Balance_graph$replicate=="Replicate19", "R10",
                                                                                                  ifelse(Balance_graph$replicate=="Replicate20", "R11", "AVG")))))))))))



#Figure to see overall balance
Balance_graph$part.x.x=factor(Balance_graph$part.x.x, levels=c("Air", 
                                                               "Larvae_gain", 
                                                               "Residual_substrate"))


Balance_graph$replicate2=factor(Balance_graph$replicate2, levels=c("AVG",
                                                                   "R11",
                                                                   "R10",
                                                                   "R9",
                                                                   "R8",
                                                                   "R7",
                                                                   "R6",
                                                                   "R5",
                                                                   "R4",
                                                                   "R3",
                                                                   "R2",
                                                                   "R1"))

Balance_graph$nutrient = factor(Balance_graph$nutrient, levels = c("DM_corrected",
                                                                   "C_corrected",
                                                                   "E_corrected",
                                                                   "N_corrected",
                                                                   "P_corrected",
                                                                   "K_corrected"))

#Exploratory figure:
ggplot(Balance_graph, aes(y= value, x=replicate2, fill=part.x.x), stat="identity")+ 
  geom_col() + 
  geom_text(aes(label = (paste0(round(value, digits = 1), "%")), group = part.x.x), position = position_stack(vjust = 0.5), size=2.5)+
  facet_wrap(~nutrient, nrow = 2)+
  labs(y=expression("Percentage of total output"))+ 
  xlab("") +
  theme(strip.background = element_rect(colour="white", fill="white"))+
  theme(strip.text = element_text(size=10, face="bold", hjust=0))+ 
  theme(panel.grid.major  = element_line(colour = "white", size = 0.2))+ 
  theme(panel.grid.minor  = element_line(colour = "white", size = 0.5))+ 
  ggtitle("") + 
  theme(plot.title=element_text(size=13, face="bold", hjust = 1, vjust=0)) + 
  theme(plot.title = element_text(hjust = 0)) + 
  theme(axis.text.x = element_text(size = 10, face = "plain",  angle = 0, hjust = 0.5, vjust=1, colour="black", lineheight = 0)) + 
  theme(strip.text.y = element_text(angle = 0)) + 
  theme(strip.background=element_rect(fill="white")) + 
  guides(fill=guide_legend(title=" ")) +
  theme(axis.title.y = element_text(size=12, face="bold")) + 
  theme(axis.title.x  = element_text(size=14, face="bold"))+ 
  theme(legend.position="bottom")+
  coord_cartesian(ylim=c())+
  scale_fill_manual(values=c("#FFA500", "#8FBC8F", "#808000"))+
  theme(legend.position="right")+
  scale_y_continuous(expand = c(0, 0),limits=c(0, 110),breaks = seq(0, 100, by = 25))+
  coord_flip()





#2.5 Creation of dataframe for Sankey Diagram (Figure 2)

Balance_average$meanstderror <- with(Balance_average, paste0(round(mean, digits=1), "", round(sderror, digits=2)))
Balance_average$meansd <- with(Balance_average, paste0(round(mean, digits=1), "", round(sd, digits=2)))


Table_balance_stderror <- Balance_average %>% select (1, 2, 7)
Table_balance_stderror <- spread(Table_balance_stderror, nutrient, meanstderror)
names(Table_balance_stderror)[1] <- "Part"
Table_balance_stderror <- Table_balance_stderror %>% select(1, 3, 2, 4, 5, 6, 7)
Table_balance_stderror




#2.6 Sankey diagrams - Figure 2
#using the data of the dataframe Table_balance_stderror, we build the following sankeys
#sankeys are saved as html and then converted to pdf with the webshot command for post-edition with the open source software Inkscape
# "?" should be replaced by the plusminus symbol

##################################### D R Y - M A T T E R #######################################

nodes = data.frame("name" = c("DM_Diet",
                              "Air emissions 26.5 (estimated by difference) %",
                              "Larvae 15.5 0.2 % ",
                              "Residual substrate 58 1 %"))

links = as.data.frame(matrix(c(0, 1, 26.5,
                               0, 2, 15.5,
                               0, 3, 58),
                             
                             byrow = TRUE, ncol = 3))
names(links) = c("source", "type", "value")



sankeyNetwork(Links = links, Nodes = nodes,
              Source = "source", Target = "type",
              Value = "value", NodeID = "name", 
              fontSize= 20, nodeWidth = 10, 
              nodePadding = 30 , 
              sinksRight = F, 
              fontFamily = "sans-serif",
              colourScale = JS("d3.scaleOrdinal(d3.schemeCategory10);"))

webshot("write here the path were the html was saved" , "gain_DM.pdf", delay = 0.2)

##################################### C A R B O N #######################################

nodes = data.frame("name" = c("C_Diet",
                              "Air emissions  23 0.8 %",
                              "Larvae 19 0.8 % ",
                              "Residual substrate 54 1.3 %"))

links = as.data.frame(matrix(c(0, 1, 23,
                               0, 2, 19,
                               0, 3, 54),
                             
                             byrow = TRUE, ncol = 3))
names(links) = c("source", "type", "value")



sankeyNetwork(Links = links, Nodes = nodes,
              Source = "source", Target = "type",
              Value = "value", NodeID = "name", 
              fontSize= 20, nodeWidth = 10, 
              nodePadding = 30 , 
              sinksRight = F, 
              fontFamily = "sans-serif",
              colourScale = JS("d3.scaleOrdinal(d3.schemeCategory10);"))


webshot("write here the path were the html was saved" , "gain_C.pdf", delay = 0.2)

##################################### E N E R G Y #######################################

nodes = data.frame("name" = c("E_Diet",
                              "Air emissions 22 1 %",
                              "Larvae 21 0.3 % ",
                              "Residual substrate 53 1.2 %"))

links = as.data.frame(matrix(c(0, 1, 22,
                               0, 2, 21,
                               0, 3, 53),
                             
                             byrow = TRUE, ncol = 3))
names(links) = c("source", "type", "value")



sankeyNetwork(Links = links, Nodes = nodes,
              Source = "source", Target = "type",
              Value = "value", NodeID = "name", 
              fontSize= 20, nodeWidth = 10, 
              nodePadding = 30 , 
              sinksRight = F, 
              fontFamily = "sans-serif",
              colourScale = JS("d3.scaleOrdinal(d3.schemeCategory10);"))

webshot("write here the path were the html was saved" , "gain_E.pdf", delay = 0.2)

##################################### N I T R O G E N #######################################

nodes = data.frame("name" = c("N_Diet",
                              "Air emissions 0.7 0.1 %",
                              "Larvae 38 0.4 % ",
                              "Residual substrate 62 1 %"))

links = as.data.frame(matrix(c(0, 1, 0.7,
                               0, 2, 38,
                               0, 3, 62),
                             
                             byrow = TRUE, ncol = 3))
names(links) = c("source", "type", "value")



sankeyNetwork(Links = links, Nodes = nodes,
              Source = "source", Target = "type",
              Value = "value", NodeID = "name", 
              fontSize= 20, nodeWidth = 10, 
              nodePadding = 30 , 
              sinksRight = F, 
              fontFamily = "sans-serif",
              colourScale = JS("d3.scaleOrdinal(d3.schemeCategory10);"))


webshot("write here the path were the html was saved" , "gain_N.pdf", delay = 0.2)

##################################### P H O S P H O R U S #######################################

nodes = data.frame("name" = c("P_Diet",
                              "Larvae 27 0.6 % ",
                              "Residual substrate 73 1.2 %"))

links = as.data.frame(matrix(c(0, 1, 27,
                               0, 2, 73),
                             
                             byrow = TRUE, ncol = 3))
names(links) = c("source", "type", "value")



sankeyNetwork(Links = links, Nodes = nodes,
              Source = "source", Target = "type",
              Value = "value", NodeID = "name", 
              fontSize= 20, nodeWidth = 10, 
              nodePadding = 30 , 
              sinksRight = F, 
              fontFamily = "sans-serif",
              colourScale = JS("d3.scaleOrdinal(d3.schemeCategory10);"))

webshot("write here the path were the html was saved" , "gain_P.pdf", delay = 0.2)

##################################### P O T A S S I U M #######################################

nodes = data.frame("name" = c("K_Diet",
                              "Larvae 14.5 0.3 % ",
                              "Residual substrate 87 1 %"))

links = as.data.frame(matrix(c(0, 1, 14.5,
                               0, 2, 87),
                             
                             byrow = TRUE, ncol = 3))
names(links) = c("source", "type", "value")



sankeyNetwork(Links = links, Nodes = nodes,
              Source = "source", Target = "type",
              Value = "value", NodeID = "name", 
              fontSize= 20, nodeWidth = 10, 
              nodePadding = 30 , 
              sinksRight = F, 
              fontFamily = "sans-serif",
              colourScale = JS("d3.scaleOrdinal(d3.schemeCategory10);"))

webshot("write here the path were the html was saved" , "gain_K.pdf", delay = 0.2)




#3.  GHG and Ammonia emissions

#3.1 Nitrous oxide
#Estimate overall N2O emissions in miligrams grams per replicate
#For that we need to estimate the total ventilated air in l/day.
#Then we need to upload the data of N2O concentration in ppm and use equation 4 of the paper to estimate the overall N2O emissions using the total ventilated air per day.


#3.1.1 Estimate total ventilated day per N2O day
#Given that for N2O all samples (except the first and the last) were taken at 12:00, for the N2O calculations 
#the day starts at 12:00 and ends at 12:00 of the next day.

chambers_summary5 <- ddply(gas_co2_o2_ch4, .(replicate, daynumbern2o, hour), summarize,
                           mean_STDP= mean(STDP, na.rm=TRUE),
                           mean_ventilation = mean(ventilation, na.rm=TRUE))

chambers_summary5$hour <- as.numeric(as.character(chambers_summary5$hour))

#to know how much N2O was produced overall for each replicate, we first estimate the average ventilation per replicate per day:
#this average ventilation (wet air) is expressed in (l/minute)
nitrous_oxide <- ddply(chambers_summary5, .(replicate, daynumbern2o), summarize, 
                       STDP = mean(mean_STDP),
                       ventilation = mean (mean_ventilation))


#Create a concatenate column to merge it with other dataset.
nitrous_oxide$concatenate <- paste(nitrous_oxide$replicate, "_", nitrous_oxide$daynumber)

#Given that the ventilation (in the dataframe nitrous_oxide) per day is given in L/min, we need to multiply this value by the number of minutes for each day to know the total L per day
#For N2O calculations a day goes from 12:00 to 12:00, except for day 1 (which goes from the start time of the experiment 
#(usually 20:00) until 12:00 of the next day) and for the last day (for N2O called "day 7"), which goes
#from 12:00 of day 6 until the time in which the experiment is stopped (usually around 09:00 of day7). 
#Therefore for day 1 and day 8, we need to calculate the number of minutes, while for days 2, 3, 4, 5 and 6, the number of 
#minutes is 1440 (the result of 60 minutes multiplied by 24 hours).


#Calculate the number of minutes in day 1

inicio <- subset(gas_co2_o2_ch4, (daynumber=="Day1"))
#keep only the first row for each replicate
inicio3 <- ddply(inicio,.(replicate),function(x) head(x,1))
#convert time (which originally is stored as a factor) to time format
inicio3$time2 <- chron(times=inicio3$time)
class(inicio3$time2)
#create a value for  midnight and have it in time format
dia <- "23:59:59"
dia <- chron(times=dia)
#informat time, how much is left for 00:00?
inicio3$timetomid <- (dia - inicio3$time2)
#in number of minutes
inicio3$timetomid2 <- 60 * hours(inicio3$timetomid) + minutes(inicio3$timetomid)
#in proportion
inicio3$timetomid3 <- inicio3$timetomid2/(24*60)


#Calculate the number of minutes in day 8 
fin <- subset(gas_co2_o2_ch4, (daynumber=="Day8"))
class(fin$hour)
fin3 <- fin%>%
  group_by(replicate) %>% #Grouping by ID
  summarise_all(funs(last(.)))
#convert time (which originally is stored as a factor) to time format
fin3$time2 <- chron(times=fin3$time)
class(fin3$time2)
#create a value for almost midnight and have it in time format
dia <- "23:59:59"
dia <- chron(times=dia)
#how much time from 00:00 to the stop of the experiment?
fin3$timetomid <- (fin3$time2)
#in number of minutes
fin3$timetomid2 <- 60 * hours(fin3$timetomid) + minutes(fin3$timetomid)
#in proportion
fin3$timetomid3 <- fin3$timetomid2/(24*60)


#Combine datasets number of minutes day 1 and day 8 
inicio_fin <- select(inicio3, replicate, daynumber, timetomid)
fin_fin <- select(fin3, replicate, daynumber, timetomid)
mix <- rbind(inicio_fin, fin_fin)
#change day8 for day7, for the new nomenclature of daynumbers for N2O estimation
mix$daynumber <- ifelse(mix$daynumber=="Day8", "Day7", "Day1")
mix$concatenate <- paste(mix$replicate, "_", mix$daynumber)


#Join the datasets nitrous oxide (ventilation) with the database mix (which shows the number of minutes in day 7 and 8)
#and estimate the total ventilation in l/day

nitrous_oxide2 <- merge(nitrous_oxide, mix, by="concatenate", all=T)
#convert to time format
nitrous_oxide2$timetomid <-  chron(times=nitrous_oxide2$timetomid)
#add the missing 24 hours for all days except day 1 and day 7 for which we will add 12:00 that will be summed to get the total number of minutes
nitrous_oxide2$totaltime <- ifelse(is.na(nitrous_oxide2$timetomid), "23:59:59", "12:00:00")
nitrous_oxide2$totaltime <- chron(times=nitrous_oxide2$totaltime)
nitrous_oxide2$time <- nitrous_oxide2$timetomid + nitrous_oxide2$totaltime
nitrous_oxide2$time <- as.character(nitrous_oxide2$time)
nitrous_oxide2$time2 <-ifelse(is.na(nitrous_oxide2$timetomid), "23:59:59", as.character(nitrous_oxide2$time))
nitrous_oxide2$time2 <- chron(times=nitrous_oxide2$time2)
#Convert hours:minutes:seconds to minutes
nitrous_oxide2$minutes <- (60 * hours(nitrous_oxide2$time2)) + minutes(nitrous_oxide2$time2)
#remove unwanted columns. 

#This dataset shows for each replicate and (n2o) day, the number of minutes with larvae inside the chambers.
nitrous_final <- nitrous_oxide2[,-(6:11),drop=FALSE]
nitrous_final$l_day <- nitrous_final$ventilation*nitrous_final$minutes


#3.1.2 Add N2O concentration and estimate overall N2O per replicate

#import dataset with n2o concentrations
nitrous_oxide_ppm <- read.csv("nitrous_oxide.csv")
#Explanation columns
#[1] date - date when the measurement was taken
#[2] code - labelling code of the syringe for each sample
#[3] Replicate - replicate number
#[4] day - day number (goes from day 1 to day 8)
#[5] ppm_outside - N2O concentration (ppm) in outside air. we measured n2o concentration in the outdoor at the start of each replicate and assumed this remained constant during the duration of the replicate
#[6] ppm_inside - N2O concentration (ppm) inside the chamber


#Estimate n2o produced inside the chamber (ppm inside - ppm outside)
nitrous_oxide_ppm$n2oproduction <- ifelse(nitrous_oxide_ppm$day=="Day1", 0, (nitrous_oxide_ppm$ppm_inside-nitrous_oxide_ppm$ppm_outside)) #ppm_outside

#correct for negatives (if a number is negative, this is converted to 0)
nitrous_oxide_ppm$n2ononegatives <- ifelse(nitrous_oxide_ppm$n2oproduction<0, 0, nitrous_oxide_ppm$n2oproduction)

#estimate average values between subsequent measurements (as explained in equation 4)
nitrous_oxide_ppm$average2days <- ifelse(nitrous_oxide_ppm$day!="Day1", ((lag(nitrous_oxide_ppm$n2ononegatives)+nitrous_oxide_ppm$n2ononegatives)/2), NA) #average for 2 days

#for day one, when experiment started, it was assumed that n2o production was 0
nitrous_oxide_ppm$average2days <- ifelse(nitrous_oxide_ppm$day=="Day1", 0, nitrous_oxide_ppm$average2days)

#select columns
nitrous_oxide_ppm <- nitrous_oxide_ppm %>% select(3, 4, 9)


#Convert everything to the dayformat of N2O

#remove day1
nitrous_oxide_ppm<- subset(nitrous_oxide_ppm, (day!="Day1"))

#change name columns
colnames(nitrous_oxide_ppm)[1] <- "replicate"
colnames(nitrous_oxide_ppm)[2] <- "day_old"
colnames(nitrous_oxide_ppm)[3] <- "nitrous_oxide"

#rename days to N2O format
nitrous_oxide_ppm$day <- ifelse(nitrous_oxide_ppm$day_old=="Day2", "Day1",
                                ifelse(nitrous_oxide_ppm$day_old=="Day3", "Day2",
                                       ifelse(nitrous_oxide_ppm$day_old=="Day4", "Day3",
                                              ifelse(nitrous_oxide_ppm$day_old=="Day5", "Day4",
                                                     ifelse(nitrous_oxide_ppm$day_old=="Day6", "Day5",
                                                            ifelse(nitrous_oxide_ppm$day_old=="Day7", "Day6", "Day7"))))))

#This dataframe contains the average N2O concentration (ppm) in the format of N2O days
nitrous_oxide_ppm <- nitrous_oxide_ppm %>% select(1, 4, 3)

#This dataset will be combined with nitrous_final (which contains the ventilation) to estimate the overall N2O per replicate

#Create concatenate column
nitrous_oxide_ppm$concatenate <- paste(nitrous_oxide_ppm$replicate, "_", nitrous_oxide_ppm$day)

#Merge the dataset nitrous final with the dataset nitrous_oxide_ppm
nitrousoxide_final <- merge(nitrous_final, nitrous_oxide_ppm, by="concatenate", all=T)

#Convert to numeric the columns STPD, ventilation,  minutes and nitrous_oxide

nitrousoxide_final$ventilation <- as.numeric(as.character(nitrousoxide_final$ventilation))
nitrousoxide_final$minutes <- as.numeric(as.character(nitrousoxide_final$minutes))
nitrousoxide_final$l_day <- as.numeric(as.character(nitrousoxide_final$l_day))
nitrousoxide_final$nitrous_oxide <- as.numeric(as.character(nitrousoxide_final$nitrous_oxide))

#Convert nitrous oxide from ppm to % in the air (dividing it by 10000)
nitrousoxide_final$n2o_percentage <- nitrousoxide_final$nitrous_oxide/10000

#Estimate the amount of N2O (in liters) for the whole duration of each day
nitrousoxide_final$n2o_liters <- (nitrousoxide_final$l_day * nitrousoxide_final$n2o_percentage)/100

#Estimate the flux per in liters/hour
nitrousoxide_final$n2o_lperhour <- 60*nitrousoxide_final$n2o_liters/nitrousoxide_final$minutes
nitrousoxide_final$n2o_mlperhour <- (60*nitrousoxide_final$n2o_liters/nitrousoxide_final$minutes)*1000


#New dataset with all nitrous oxide aggregated (not anymore per day, but for each replicate)
#This dataset will be called later to prepare Table 2
nitrousoxide_final2 <- ddply(nitrousoxide_final, .(replicate), summarize, 
                             sum_N2O_liters= sum(n2o_liters, na.rm=TRUE))
#multiply litters by 1.965179 (molar mass of n2o (44.02 g/mol) divided by 22.4 (which is the number of liters of any gas in one mol))
nitrousoxide_final2$n2ograms <- nitrousoxide_final2$sum_N2O_liters*1.965179
nitrousoxide_final2$ngrams <- nitrousoxide_final2$n2ograms *  0.6363636 #N proportion in N2O ((14.01*2)/44)
nitrousoxide_final2$co2equivalentsgrams <- nitrousoxide_final2$n2ograms*298



#3.1.3. Create dataframes for figure and plot figures
#Create newdataset for figure on nitrous oxide
nitrousoxide_df_figure <- nitrousoxide_final %>% select (2, 3, 14)

#Prepare dataset for the N2O panel on Figure 3 and N2O panel per replicate for Supplementary Figure 3
# change nomenclarute of days for figure
#For figure we need 8 days

nitrousoxide_df_figure$newday <- ifelse(nitrousoxide_df_figure$daynumbern2o=="Day1", "Day2",
                                        ifelse(nitrousoxide_df_figure$daynumbern2o=="Day2", "Day3",
                                               ifelse(nitrousoxide_df_figure$daynumbern2o=="Day3", "Day4",
                                                      ifelse(nitrousoxide_df_figure$daynumbern2o=="Day4", "Day5",
                                                             ifelse(nitrousoxide_df_figure$daynumbern2o=="Day5", "Day6",
                                                                    ifelse(nitrousoxide_df_figure$daynumbern2o=="Day6", "Day7", "Day8"))))))


#Add hour column, select relevant columns, change column names and bind this dataset with an empty one that contains
#per replicate the days and hour times in which there were no measurements (this is needed to have the same format of 
#figure than CO2, NH3, O2, CH4, RQ, ENERGY)

#Add hour in which the N2O was collected and edit name of columns
nitrousoxide_df_figure$hour <- ifelse(nitrousoxide_df_figure$newday!="Day8", "12", "8") 
nitrousoxide_df_figure <- nitrousoxide_df_figure %>% select (1, 4, 5, 3)
names(nitrousoxide_df_figure) [1] <- "replicate"
names(nitrousoxide_df_figure) [2] <- "day"
names(nitrousoxide_df_figure) [3] <- "hour"
names(nitrousoxide_df_figure) [4] <- "ml_n2o_hour"


#To build the figure as the ones for CO2, CH4, N2O in Figure3, we need to have values per hour.
#Given that for N2O we only have one measurement per day, we will add a formated dataset for this called df_figure_n2o
#This datasets contains NA values for all hours in between the N2O measurements

df_figure_n2o <- read.csv("df_figure_n2o.csv")
#Column explanation
#[1]replicate - Replicate code (Replicate8, Replicate9, etc)
#[2]day - Number of day for each replicate (goes from Day 1 to Day 8). This was created for the Figures (days go from 00:00 to 00:00) and used for the analysis
#[3]hour - Hour of the day (in 24:00 format)
#[4]ml_n2o_hour - Contains NA values for all hours in between N2O measurements

#Add this dataset to the one were we already had the measurements
nitrousoxide_df_figure <- rbind(nitrousoxide_df_figure, df_figure_n2o)
nitrousoxide_df_figure$ml_n2o_hour <- as.numeric(as.character(nitrousoxide_df_figure$ml_n2o_hour))
nitrousoxide_df_figure$hour <- as.numeric(as.character(nitrousoxide_df_figure$hour))


#plot figure
nitrousoxide_df_figure$replicate2 <- ifelse(nitrousoxide_df_figure$replicate=="Replicate8", "R1",
                                            ifelse(nitrousoxide_df_figure$replicate=="Replicate9", "R2",
                                                   ifelse(nitrousoxide_df_figure$replicate=="Replicate10", "R3",
                                                          ifelse(nitrousoxide_df_figure$replicate=="Replicate11", "R4",
                                                                 ifelse(nitrousoxide_df_figure$replicate=="Replicate12", "R5",
                                                                        ifelse(nitrousoxide_df_figure$replicate=="Replicate13", "R6",
                                                                               ifelse(nitrousoxide_df_figure$replicate=="Replicate14", "R7",
                                                                                      ifelse(nitrousoxide_df_figure$replicate=="Replicate15", "R8",
                                                                                             ifelse(nitrousoxide_df_figure$replicate=="Replicate16", "R9",
                                                                                                    ifelse(nitrousoxide_df_figure$replicate=="Replicate19", "R10",
                                                                                                           ifelse(nitrousoxide_df_figure$replicate=="Replicate20", "R11", "AVG")))))))))))


#Order factors for figure
nitrousoxide_df_figure$replicate2=factor(nitrousoxide_df_figure$replicate2, levels=c("R1",
                                                                                     "R2",
                                                                                     "R3",
                                                                                     "R4",
                                                                                     "R5",
                                                                                     "R6",
                                                                                     "R7",
                                                                                     "R8",
                                                                                     "R9",
                                                                                     "R10",
                                                                                     "R11"))

nitrousoxide_df_figure$day= factor(nitrousoxide_df_figure$day, levels =c("Day1",
                                                                         "Day2",
                                                                         "Day3",
                                                                         "Day4",
                                                                         "Day5",
                                                                         "Day6",
                                                                         "Day7",
                                                                         "Day8"))

S5 <- ggplot(data=nitrousoxide_df_figure, aes(x=hour, y=ml_n2o_hour, fill=replicate))+
  geom_bar(stat = "identity", position = "dodge", width=20)+
  facet_wrap(~day, ncol=8)+
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  theme_bw()+
  theme(axis.text.x = element_text(size=8, angle=0, vjust = 0.5),
        axis.text.y = element_text(size=10, angle=0),
        legend.title = element_blank())+
  scale_y_continuous(name="N2O (ml/h)", expand = c(0,0), limits = c(0, 0.5))+
  scale_x_continuous(name="Time of the day (hours)", expand = c(0, 0), breaks = c(12))+
  theme(panel.spacing = unit(0.1, "lines"))+
  ggtitle("E")+
  scale_fill_manual(values=c("#922B21",
                             "#76448A", "#76448A",
                             "#1F618D", "#1F618D",
                             "#B7950B", "#B7950B",
                             "#1E8449", "#1E8449",
                             "#283747", "#283747"))+
  theme(legend.position = "none")

S5

nitrousoxide_df_figure_summary <- ddply(nitrousoxide_df_figure, .(day, hour), summarize,
                                        n2o_mean = mean(ml_n2o_hour),
                                        n2o_sd = std.error(ml_n2o_hour))

A5 <- ggplot(data=nitrousoxide_df_figure_summary, aes(x=hour, y=n2o_mean))+
  geom_point(aes(y=n2o_mean), size=2)+
  geom_errorbar(aes(ymin=(n2o_mean-n2o_sd), ymax=(n2o_mean+n2o_sd)), size=1)+
  facet_wrap(~day, ncol=8)+
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  theme_bw()+
  theme(axis.text.x = element_text(size=8, angle=0, vjust = 0.5),
        axis.text.y = element_text(size=10, angle=0),
        legend.title = element_blank())+
  scale_y_continuous(name="N2O (ml/h)", expand = c(0.05,0), limits=c(0, 0.2)) +
  scale_x_continuous(name="Time of the day (hours)", expand = c(0, 0))+
  theme(panel.spacing = unit(0.15, "lines"))+
  ggtitle("E")+
  theme(legend.position = "bottom")+
  guides(col=guide_legend(nrow=1))

A5



#3.2 Ammonia

#3.2.1 Prepare dataset for figures
#Import dataset ammonia
ammonia <- read.csv("ammonia.csv")

#Explanation of columns
#[1] "chamber" - Refers to the respiration chamber in which the data was measured. In the experiments there were two climate respiration chambers: number 5 and number 6.
#[2] "date" - Date of the measurement
#[3] "time" - Time of the measurement
#[4] "NH3_ppm" - Concentration of NH3 in ppm
#[5] "verv_stp" - Air ventilation (L/min) corrected for temperature and pressure
#[6] "vol_stp" - Volume of the chamber (L) corrected for pressure and temperature
#[7] "NH3" - Ammonia in L/day
#[8] "batch" - Number of batch of diet and starters
#[9] "start_date_exp" - Start data of the experimental replicate
#[10] "datetime" - Combined date and time 
#[11] "replicate" - Replicate number
#[12] "concatenate" - Concatenate of Batch number and datetime
#[13] "hour" - Hour of the day in 24h format
#[14] "minute" - Minute at which the measurement was taken (from 0 to 60)
#[15] "second" - 	Seconds (from 0 to 60)
#[16] "daynumber"	 - Day number (from day1 and day8) in which the measurement took place

#replicates 19 and 20 are not included here because the ammonia sensors had a technical problem

#Calculate Ammonia production per hour (units L/day)
Ammonia_summary <- ddply(ammonia, .(replicate, daynumber, hour), summarize, 
                         NH3_mean = mean (NH3, na.rm=TRUE))
Ammonia_summary$hour <- as.numeric(as.character(Ammonia_summary$hour))


#Calculate NH3 (in grams per replicate)
#Use the conversion factor from liters to grams and divide the result by 24 to have grams produced per hour
#To convert from liters to grams, use the following conversion factors (molar mass/22.4)
#NH3 ---> 17.031/22.4 = 0.7603125

Ammonia_summary$ml_NH3_hour <- (Ammonia_summary$NH3_mean/24)*1000
Ammonia_summary$weight_nh3_grams <-(Ammonia_summary$NH3_mean * 0.7603125)/24

#Ammonia_sumary_mean contains the overall ammonia per day and hour (mean of all replicates)
Ammonia_summary_mean <- ddply(Ammonia_summary, .(daynumber, hour), summarize,
                              mean_ml_NH3_hour = mean(ml_NH3_hour),
                              sderror = std.error(ml_NH3_hour))

#Create concatenate column and remove the last measurements in day 8 to standarize the end time (day 8, hour 8 and 9)
Ammonia_summary_mean$concatenate <- with(Ammonia_summary_mean, paste0(daynumber, "_", hour))
Ammonia_summary_mean <- subset(Ammonia_summary_mean, (concatenate!= "Day8_8" & concatenate!= "Day8_9"))

#3.2.2 Ammonia Figures

#Replace naming of replicate number
Ammonia_summary$replicate2 <- ifelse(Ammonia_summary$replicate=="Replicate8", "R1",
                                     ifelse(Ammonia_summary$replicate=="Replicate9", "R2",
                                            ifelse(Ammonia_summary$replicate=="Replicate10", "R3",
                                                   ifelse(Ammonia_summary$replicate=="Replicate11", "R4",
                                                          ifelse(Ammonia_summary$replicate=="Replicate12", "R5",
                                                                 ifelse(Ammonia_summary$replicate=="Replicate13", "R6",
                                                                        ifelse(Ammonia_summary$replicate=="Replicate14", "R7",
                                                                               ifelse(Ammonia_summary$replicate=="Replicate15", "R8",
                                                                                      ifelse(Ammonia_summary$replicate=="Replicate16", "R9",
                                                                                             ifelse(Ammonia_summary$replicate=="Replicate19", "R10",
                                                                                                    ifelse(Ammonia_summary$replicate=="Replicate20", "R11", "AVG")))))))))))


#Order factors for figure
Ammonia_summary$replicate2=factor(Ammonia_summary$replicate2, levels=c("R1",
                                                                       "R2",
                                                                       "R3",
                                                                       "R4",
                                                                       "R5",
                                                                       "R6",
                                                                       "R7",
                                                                       "R8",
                                                                       "R9",
                                                                       "R10",
                                                                       "R11"))

Ammonia_summary$daynumber= factor(Ammonia_summary$daynumber, levels =c("Day1",
                                                                       "Day2",
                                                                       "Day3",
                                                                       "Day4",
                                                                       "Day5",
                                                                       "Day6",
                                                                       "Day7",
                                                                       "Day8"))

#Supplementary Figure Ammonia

S4<- ggplot(data=Ammonia_summary, aes(x=hour, y=ml_NH3_hour, group=replicate2, color=replicate2))+
  geom_line(size=1)+
  facet_wrap(~daynumber, ncol=8)+
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  theme_bw()+
  theme(axis.text.x = element_text(size=8, angle=0, vjust = 0.5),
        axis.text.y = element_text(size=10, angle=0),
        legend.title = element_blank())+
  scale_y_continuous(name="NH3(ml/hour)", expand = c(0,0), limits = c(0, 11))+
  scale_x_continuous(name="Time of the day (hours)", expand = c(0, 0))+
  theme(panel.spacing = unit(0.1, "lines"))+
  ggtitle("D")+
  theme(legend.position = "none")+
  scale_color_manual(values=c("#922B21",
                              "#76448A", "#76448A",
                              "#1F618D", "#1F618D",
                              "#B7950B", "#B7950B",
                              "#1E8449", "#1E8449",
                              "#283747", "#283747"))+
  guides(col=guide_legend(nrow=1))

S4



#Figure 3- Ammonia

A6 <- ggplot(data=Ammonia_summary_mean, aes(x=hour, y=mean_ml_NH3_hour))+
  geom_line(size=1)+
  geom_ribbon(aes(ymin=(mean_ml_NH3_hour-sderror), ymax=(mean_ml_NH3_hour+sderror)), alpha=0.2, col="#7c7878") +
  facet_wrap(~daynumber, ncol=8)+
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  theme_bw()+
  theme(axis.text.x = element_text(size=8, angle=0, vjust = 0.5),
        axis.text.y = element_text(size=10, angle=0),
        legend.title = element_blank())+
  scale_y_continuous(name="NH3(ml/hour)", expand = c(0,0), limits = c(0, 11))+
  scale_x_continuous(name="Time of the day (hours)", expand = c(0, 0), breaks = c(0, 12, 0))+
  theme(panel.spacing = unit(0.2, "lines"))+
  ggtitle("D")+
  guides(col=guide_legend(ncol=7))

A6



#3.3 Overall GHG emissions (N2O, CO2, CH4, energy) and total Nitrogen per kg larvae gain (For Table 2)
#this will be three steps
#3.3.1 overall GHG emissions per replicate
#3.3.2 fresh and dry larvae yield per replicate 
#3.3.3 Both dataframes are combined to estimate the emissions per kg of dry larvae
#3.3.4 There is an additional calculation for methane in which some outliers were removed


#3.3.1 overall GHG emissions per replicate
#For CO2, energy and CH4
gasses_weight2 <- gasses_weight %>% select (1, 2, 3)
gasses_weight3 <- gasses_weight %>% select (1, 2, 3, 4)
gasses_weight2 $replicate=factor(gasses_weight2$replicate, levels=c('Replicate8',
                                                                    'Replicate9',
                                                                    'Replicate10',
                                                                    'Replicate11',
                                                                    'Replicate12',
                                                                    'Replicate13',
                                                                    'Replicate14',
                                                                    'Replicate15',
                                                                    'Replicate16',
                                                                    'Replicate17',
                                                                    'Replicate18',
                                                                    'Replicate19',
                                                                    'Replicate20'))


#for N2O
nitrousoxide_weight <- nitrousoxide_final2
nitrousoxide_weight <- nitrousoxide_weight %>% select (1, 3)


#for Nitrogen
#we call a dataframe containing the total N lost in acid and condensed water (this dataset was created before)
total_n


#Create one dataset that contains CO2, CH4, N2O and Nitrogen
emission_factors <- merge(gasses_weight3, nitrousoxide_weight, by="replicate", all=T)
emission_factors <- merge(emission_factors, total_n, by="replicate", all=T)

#Calculate CO2eq
emission_factors$co2eq <- (emission_factors$total_ch4_grams*34) + (emission_factors$n2ograms*298)

#Summary emissions factors
emission_factors2 <- gather(emission_factors, "Variable", "grams", 2:7)





#3.3.2 fresh and dry larvae yield per replicate 
#fresh weight
larval_biomass_fresh2 <- subset(fresh_biomass_replicate, (part=="larvae")| (part=="starter"))
larval_biomass_fresh2 <- larval_biomass_fresh2[, -4, drop=FALSE]
rr <- spread(larval_biomass_fresh2, part, freshweight_grams)
rr$gain <- rr$larvae - rr$starter
rr <- rr[, -(2:3), drop=FALSE]

#dry weight
larval_drymatter <- subset(nutritional_results, (part=="larvae"))



#3.3.3 Both dataframes are combined to estimate the emissions per kg of dry larvae
emission_factors2 <-  merge(emission_factors2, rr, by="replicate", all=T)
emission_factors2 <-  merge(emission_factors2, larval_drymatter, by="replicate", all=T)

emission_factors2 <- emission_factors2[, -(7:14), drop=FALSE]

emission_factors2$dryweight_grams <- emission_factors2$gain * emission_factors2$DM

#convert methane and n2o to miligrams
emission_factors2$grams <- ifelse(emission_factors2$Variable == "total_ch4_grams" | emission_factors2$Variable == "n2ograms", emission_factors2$grams*1000, emission_factors2$grams)
emission_factors2$Variable <- ifelse(emission_factors2$Variable == "total_ch4_grams", "total_ch4_mg", emission_factors2$Variable)
emission_factors2$Variable <- ifelse(emission_factors2$Variable == "n2ograms", "n2o_mg", emission_factors2$Variable)

#estimate emissions per kg of fresh and dry larvae
emission_factors2$grams_perkg_fresh_larvae <-  (emission_factors2$grams * 1000) / emission_factors2$gain #emissions are kg of gas
emission_factors2$grams_perkg_dry_larvae <- (emission_factors2$grams * 1000) / emission_factors2$dryweight_grams #emissions are per kg of gas

#add concatenate column
emission_factors2$concatenate <- with(emission_factors2, paste0(replicate, "_", Variable))

##Create a dataframe that will be used later for starch correction:
heat_production_kg_gain <- emission_factors2

#Average emissions per per kg of larvae (all replicated are averaged)
emission_factors_summary <- ddply(emission_factors2, .(Variable), summarize,
                                  mean_fresh = mean(grams_perkg_fresh_larvae),
                                  std_fresh = sd(grams_perkg_fresh_larvae),
                                  mean_dry = mean(grams_perkg_dry_larvae),
                                  std_dry = sd(grams_perkg_dry_larvae))

#The standard deviation of methane is very high because the values obtained in replicate 20 were an outlier
methane2 <- subset(emission_factors2, (Variable=="total_ch4_mg"))

ggplot(data=methane2, aes(x=replicate, y=grams_perkg_dry_larvae)) +
  geom_bar(stat="identity")

#Calculation of standard deviation without the outlier
#this value will be added as a footnote in Table2:
methane3 <- subset(methane2, (replicate!= "Replicate20"))
methane4 <- ddply(methane3, .(Variable), summarize,
                  mean_fresh = mean(grams_perkg_dry_larvae),
                  std_fresh = sd(grams_perkg_dry_larvae))

methane4

#Format table to look like Table 2:
emission_factors_summary$fresh <- with(emission_factors_summary, paste0(round(mean_fresh, digits = 1), "", round(std_fresh, digits = 2)))
emission_factors_summary$dry <- with(emission_factors_summary, paste0(round(mean_dry, digits = 1), "", round(std_dry, digits = 2)))

emission_factors_summary <- emission_factors_summary[, -(2:5), drop=FALSE]

emission_factors_summary <- data.frame(t(emission_factors_summary))

emission_factors_summary <- emission_factors_summary[, c(5,4,2,1,3,6)]
emission_factors_summary <- emission_factors_summary %>% select(1,2,3,4,5,6)

names(emission_factors_summary)[1] <- "g CO2"
names(emission_factors_summary)[2] <- "mg CH4"
names(emission_factors_summary)[3] <- "g N"
names(emission_factors_summary)[4] <- "g CO2eq"
names(emission_factors_summary)[5] <- "mg N2O"
names(emission_factors_summary)[6] <- "kJ"


emission_factors_summary <- emission_factors_summary[, c(1, 2, 5, 4, 3, 6)]

emission_factors_summary

#Save Table2
#write.csv(emission_factors_summary, file = "Table 2.csv", row.names = TRUE)  






#4. Figure 3 and Figure S3
#Figure 3
chambers_summary3 <- chambers_summary2

chambers_summary3$heat_hour <- chambers_summary2$mean_heat/24
chambers_summary3$l_co2_hour <- chambers_summary2$mean_CO2/24
chambers_summary3$l_ch4_hour <- chambers_summary2$mean_CH4/24
chambers_summary3$l_o2_hour <- chambers_summary2$mean_O2/24
chambers_summary3$RQ_1 <- chambers_summary2$mean_RQ
chambers_summary3 <- chambers_summary3[, -(4:17)]


#dataset for summarized figure

chambers_summary3_mean <- ddply(chambers_summary3, .(daynumber, hour), summarize,
                                co2_mean = mean(l_co2_hour),
                                co2_sd = std.error(l_co2_hour),
                                ch4_mean = mean(l_ch4_hour),
                                ch4_sd = std.error(l_ch4_hour),
                                o2_mean = mean(l_o2_hour),
                                o2_sd = std.error(l_o2_hour),
                                RQ_mean = mean(RQ_1),
                                RQ_sd = std.error(RQ_1),
                                energy_mean = mean(heat_hour),
                                energy_sd = std.error(heat_hour))



chambers_summary3$replicate2 <- ifelse(chambers_summary3$replicate=="Replicate8", "R1",
                                       ifelse(chambers_summary3$replicate=="Replicate9", "R2",
                                              ifelse(chambers_summary3$replicate=="Replicate10", "R3",
                                                     ifelse(chambers_summary3$replicate=="Replicate11", "R4",
                                                            ifelse(chambers_summary3$replicate=="Replicate12", "R5",
                                                                   ifelse(chambers_summary3$replicate=="Replicate13", "R6",
                                                                          ifelse(chambers_summary3$replicate=="Replicate14", "R7",
                                                                                 ifelse(chambers_summary3$replicate=="Replicate15", "R8",
                                                                                        ifelse(chambers_summary3$replicate=="Replicate16", "R9",
                                                                                               ifelse(chambers_summary3$replicate=="Replicate19", "R10",
                                                                                                      ifelse(chambers_summary3$replicate=="Replicate20", "R11", "AVG")))))))))))


#Order factors for figure
chambers_summary3$replicate2=factor(chambers_summary3$replicate2, levels=c("R1",
                                                                           "R2",
                                                                           "R3",
                                                                           "R4",
                                                                           "R5",
                                                                           "R6",
                                                                           "R7",
                                                                           "R8",
                                                                           "R9",
                                                                           "R10",
                                                                           "R11"))

chambers_summary3$daynumber= factor(chambers_summary3$daynumber, levels =c("Day1",
                                                                           "Day2",
                                                                           "Day3",
                                                                           "Day4",
                                                                           "Day5",
                                                                           "Day6",
                                                                           "Day7",
                                                                           "Day8"))







#CO2
A1<- ggplot(data=chambers_summary3_mean, aes(x=hour, y=co2_mean))+
  geom_line(size=1)+
  geom_ribbon(aes(ymin=(co2_mean-co2_sd), ymax=(co2_mean+co2_sd)), alpha=0.2, col="#7c7878") +
  facet_wrap(~daynumber, ncol=8)+
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  theme_bw()+
  theme(axis.text.x = element_text(size=8, angle=0, vjust = 0.5),
        axis.text.y = element_text(size=10, angle=0),
        legend.title = element_blank())+
  scale_y_continuous(name="CO2 (l/hour)", expand = c(0,0)) +
  scale_x_continuous(name="Time of the day (hours)", expand = c(0, 0), breaks = c(0, 12, 0))+
  theme(panel.spacing = unit(0.15, "lines"))+
  ggtitle("A")+
  theme(legend.position = "bottom")+
  guides(col=guide_legend(nrow=1))
A1

#Oxygen
A11 <- ggplot(data=chambers_summary3_mean, aes(x=hour, y=o2_mean))+
  geom_line(size=1)+
  geom_ribbon(aes(ymin=(co2_mean-co2_sd), ymax=(co2_mean+co2_sd)), alpha=0.2, col="#7c7878") +
  facet_wrap(~daynumber, ncol=8)+
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  theme_bw()+
  theme(axis.text.x = element_text(size=8, angle=0, vjust = 0.5),
        axis.text.y = element_text(size=10, angle=0),
        legend.title = element_blank())+
  scale_y_continuous(name="O2 (l/hour)", expand = c(0,0)) +
  scale_x_continuous(name="Time of the day (hours)", expand = c(0, 0), breaks = c(0, 12, 0))+
  theme(panel.spacing = unit(0.15, "lines"))+
  ggtitle("A")+
  theme(legend.position = "bottom")+
  guides(col=guide_legend(nrow=1))

A11


#energy

A2 <- ggplot(data=chambers_summary3_mean, aes(x=hour, y=energy_mean))+
  geom_line(size=1)+
  geom_ribbon(aes(ymin=(energy_mean-energy_sd), ymax=(energy_mean+energy_sd)), alpha=0.2, col="#7c7878") +
  facet_wrap(~daynumber, ncol=8)+
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  theme_bw()+
  theme(axis.text.x = element_text(size=8, angle=0, vjust = 0.5),
        axis.text.y = element_text(size=10, angle=0),
        legend.title = element_blank())+
  scale_y_continuous(name="Heat (kJ/hour)", expand = c(0,0), limits=c(0, 300)) +
  scale_x_continuous(name="Time of the day (hours)", expand = c(0, 0), breaks = c(0, 12, 0))+
  theme(panel.spacing = unit(0.15, "lines"))+
  ggtitle("B")+
  theme(legend.position = "bottom")+
  guides(col=guide_legend(nrow=1))
A2

#CH4
A3 <- ggplot(data=chambers_summary3_mean, aes(x=hour, y=RQ_mean))+
  geom_line(size=1)+
  geom_ribbon(aes(ymin=(RQ_mean-RQ_sd), ymax=(RQ_mean+RQ_sd)), alpha=0.2, col="#7c7878") +
  facet_wrap(~daynumber, ncol=8)+
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  theme_bw()+
  theme(axis.text.x = element_text(size=8, angle=0, vjust = 0.5),
        axis.text.y = element_text(size=10, angle=0),
        legend.title = element_blank())+
  scale_y_continuous(name="RQ", expand = c(0,0), limits=c(0, 2)) +
  scale_x_continuous(name="Time of the day (hours)", expand = c(0, 0), breaks = c(0, 12, 0))+
  theme(panel.spacing = unit(0.15, "lines"))+
  ggtitle("C")+
  theme(legend.position = "bottom")+
  guides(col=guide_legend(nrow=1))
A3

#Methane
A4<- ggplot(data=chambers_summary3_mean, aes(x=hour, y=ch4_mean*1000))+
  geom_line(size=1)+
  geom_ribbon(aes(ymin=(ch4_mean*1000-ch4_sd*1000), ymax=(ch4_mean*1000+ch4_sd*1000)), alpha=0.2, col="#7c7878") +
  facet_wrap(~daynumber, ncol=8)+
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  theme_bw()+
  theme(axis.text.x = element_text(size=8, angle=0, vjust = 0.5),
        axis.text.y = element_text(size=10, angle=0),
        legend.title = element_blank())+
  scale_y_continuous(name="CH4 (ml/hour)", expand = c(0,0), limits = c(0, 5), breaks = c(0, 1.5, 3, 4.5)) +
  scale_x_continuous(name="Time of the day (hours)", expand = c(0, 0), breaks = c(0, 12, 0))+
  theme(panel.spacing = unit(0.15, "lines"))+
  ggtitle("D")+
  theme(legend.position = "bottom")+
  guides(col=guide_legend(nrow=1))

A4

#NH3 - call figure previously created
A6 

#N2O
A5


#Combine them in one figure with the gridextra package
grid.arrange(A1, A2, A3, A4, A6, A5, ncol=3)
Figure3 <- arrangeGrob(A1, A2, A3, A4, A5, A6, ncol=3) #generates g
#ggsave(file="Figure3.png", width = 30, height = 15, units="cm", dpi=300, Figure3) #saves g
#ggsave(file="Figure3.pdf", width = 30, height = 15, units="cm", dpi=300, Figure3)




#For Suppementary Figure S3
#CO2, CH4 and Energy


#plot with all replicates
#CO2
S1 <- ggplot(data=chambers_summary3, aes(x=hour, y=l_co2_hour, group=replicate2, color=replicate2))+
  geom_line(size=1)+
  #geom_text(data = chambers_summary2[chambers_summary2$hour == "20" & chambers_summary2$daynumber=="Day5",
  #                     ], aes(label = replicate), hjust = 0.7, vjust = 1)+
  facet_wrap(~daynumber, ncol=8)+
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  theme_bw()+
  theme(axis.text.x = element_text(size=8, angle=0, vjust = 0.5),
        axis.text.y = element_text(size=10, angle=0),
        legend.title = element_blank())+
  scale_y_continuous(name="CO2 (l/hour)", expand = c(0,0)) +
  scale_x_continuous(name="Time of the day (hours)", expand = c(0, 0), breaks = c(0, 12, 0))+
  theme(panel.spacing = unit(0.15, "lines"))+
  ggtitle("A")+
  theme(legend.position = "none")+
  scale_color_manual(values=c("#922B21",
                              "#76448A", "#76448A",
                              "#1F618D", "#1F618D",
                              "#B7950B", "#B7950B",
                              "#1E8449", "#1E8449",
                              "#283747", "#283747"))

S1

#energy

S2 <- ggplot(data=chambers_summary3, aes(x=hour, y=kj, group=replicate2, color=replicate2))+
  geom_line(size=1)+
  #geom_text(data = chambers_summary2[chambers_summary2$hour == "20" & chambers_summary2$daynumber=="Day5",
  #                     ], aes(label = replicate), hjust = 0.7, vjust = 1)+
  facet_wrap(~daynumber, ncol=8)+
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  theme_bw()+
  theme(axis.text.x = element_text(size=8, angle=0, vjust = 0.5),
        axis.text.y = element_text(size=10, angle=0),
        legend.title = element_blank())+
  scale_y_continuous(name="Heat (KJ/hour)", expand = c(0,0), limits=c(0, 400))+
  scale_x_continuous(name="Time of the day (hours)", expand = c(0, 0), breaks = c(0, 12, 0))+
  theme(panel.spacing = unit(0.15, "lines"))+
  ggtitle("B")+
  scale_color_manual(values=c("#922B21",
                              "#76448A", "#76448A",
                              "#1F618D", "#1F618D",
                              "#B7950B", "#B7950B",
                              "#1E8449", "#1E8449",
                              "#283747", "#283747"))+
  theme(legend.position = "none")

S2

#methane
S3 <- ggplot(data=chambers_summary3, aes(x=hour, y=(l_ch4_hour*1000), group=replicate2, color=replicate2))+
  geom_line(size=1)+
  #geom_text(data = chambers_summary2[chambers_summary2$hour == "20" & chambers_summary2$daynumber=="Day5",
  #                     ], aes(label = replicate), hjust = 0.7, vjust = 1)+
  facet_wrap(~daynumber, ncol=8)+
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  theme_bw()+
  theme(axis.text.x = element_text(size=8, angle=0, vjust = 0.5),
        axis.text.y = element_text(size=10, angle=0),
        legend.title = element_blank())+
  scale_y_continuous(name="CH4 (ml/hour)", expand = c(0,0)) +
  scale_x_continuous(name="Time of the day (hours)", expand = c(0, 0), breaks = c(0, 12, 0))+
  theme(panel.spacing = unit(0.15, "lines"))+
  ggtitle("C")+
  theme(legend.position = "none")+
  scale_color_manual(values=c("#922B21",
                              "#76448A", "#76448A",
                              "#1F618D", "#1F618D",
                              "#B7950B", "#B7950B",
                              "#1E8449", "#1E8449",
                              "#283747", "#283747"))

S3

#Ammonia
#Call figure created before in the Ammonia section
S4

#N2O
#Call S5 which was created before
S5 


#RQ

S6 <- ggplot(data=chambers_summary3, aes(x=hour, y=RQ_1, group=replicate2, color=replicate2))+
  geom_line(size=1)+
  #geom_text(data = chambers_summary2[chambers_summary2$hour == "20" & chambers_summary2$daynumber=="Day5",
  #                     ], aes(label = replicate), hjust = 0.7, vjust = 1)+
  facet_wrap(~daynumber, ncol=8)+
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  theme_bw()+
  theme(axis.text.x = element_text(size=8, angle=0, vjust = 0.5),
        axis.text.y = element_text(size=10, angle=0),
        legend.title = element_blank())+
  scale_y_continuous(name="RQ", expand = c(0,0), limits=c(0, 3.1), breaks = c(0, 0.5, 1, 1.5, 2, 2.5, 3)) +
  scale_x_continuous(name="Time of the day (hours)", expand = c(0, 0), breaks = c(0, 12, 0))+
  theme(panel.spacing = unit(0.15, "lines"))+
  ggtitle("F")+
  theme(legend.position = "bottom")+
  scale_color_manual(values=c("#922B21",
                              "#76448A", "#76448A",
                              "#1F618D", "#1F618D",
                              "#B7950B", "#B7950B",
                              "#1E8449", "#1E8449",
                              "#283747", "#283747"))+
  guides(col=guide_legend(nrow =1))

S6

#Combine and save them i nthe same Figure using the extragrid package
grid.arrange(S1, S2, S3, S4, S5, S6, ncol=2)
FigureS3 <- arrangeGrob(S1, S2, S3, S4, S5, S6, ncol=2) #generates g
#ggsave(file="FigureS3.png", width = 35, height = 20, units="cm", dpi=300, FigureS4) #saves g
#ggsave(file="FigureS3.pdf", width = 35, height = 20, units="cm", dpi=300, FigureS4) #saves g







#5. Analysis for Supplementary Figures
#5.1 Starch in residues (Figure S1)


#Residual starch in residual substrate vs diet

Starch_analysis <- subset(nutritional_overall, (part.x=="Diet" | part.x=="Residual_substrate"))
Starch_analysis <- Starch_analysis %>% select(1, 3, 12)
Starch_analysis <- spread(Starch_analysis, part.x, STARCH_overall)
Starch_analysis$proportion <- (Starch_analysis$Residual_substrate/Starch_analysis$Diet)
Starch_analysis <- Starch_analysis %>% select(1,4)
Starch_analysis$stderror <- NA

#Figure
Starch_analysis_summary <- data.frame("replicate" = c("Average"), "proportion" = mean(Starch_analysis$proportion), "stderror" = std.error(Starch_analysis$proportion))
Starch_analysis <- rbind(Starch_analysis, Starch_analysis_summary)



Starch_analysis$replicate2 <- ifelse(Starch_analysis$replicate=="Replicate8", "R1",
                                     ifelse(Starch_analysis$replicate=="Replicate9", "R2",
                                            ifelse(Starch_analysis$replicate=="Replicate10", "R3",
                                                   ifelse(Starch_analysis$replicate=="Replicate11", "R4",
                                                          ifelse(Starch_analysis$replicate=="Replicate12", "R5",
                                                                 ifelse(Starch_analysis$replicate=="Replicate13", "R6",
                                                                        ifelse(Starch_analysis$replicate=="Replicate14", "R7",
                                                                               ifelse(Starch_analysis$replicate=="Replicate15", "R8",
                                                                                      ifelse(Starch_analysis$replicate=="Replicate16", "R9",
                                                                                             ifelse(Starch_analysis$replicate=="Replicate19", "R10",
                                                                                                    ifelse(Starch_analysis$replicate=="Replicate20", "R11", "AVG")))))))))))





Starch_analysis$replicate2=factor(Starch_analysis$replicate2, levels=c("R1","R2", "R3","R4","R5","R6","R7","R8","R9","R10","R11", "AVG"))





graph_starch <- ggplot(Starch_analysis, aes(y= proportion, x=replicate2))+ 
  geom_bar(stat="identity", fill = "white", colour = "black") + 
  geom_errorbar(aes(ymin=proportion-stderror, ymax=proportion+stderror), width=0.3)+
  labs(y=expression("Starch in residues/Starch in diet"))+ 
  xlab("") +
  theme_classic()+
  theme(strip.background = element_rect(colour="white", fill="white"))+
  theme(strip.text = element_text(size=10, face="bold", hjust=0))+ 
  theme(panel.grid.major  = element_line(colour = "white", size = 0.2))+ 
  theme(panel.grid.minor  = element_line(colour = "white", size = 0.5))+ 
  ggtitle("") + 
  theme(plot.title=element_text(size=13, face="bold", hjust = 0, vjust=0)) + 
  theme(plot.title = element_text(hjust = 0)) + 
  theme(axis.text.x = element_text(size = 12, face = "plain",  angle = 0, hjust = 0.5, vjust=0.5, colour="black", lineheight = 0)) + 
  theme(axis.text.y = element_text(size = 12, face = "plain",  angle = 0, hjust = 0.5, vjust=0.5, colour="black", lineheight = 0)) +
  theme(strip.text.y = element_text(angle = 0)) + 
  theme(strip.background=element_rect(fill="white")) + 
  guides(fill=guide_legend(title=" ")) +
  theme(axis.title.y = element_text(size=12, face="plain")) + 
  theme(axis.title.x  = element_text(size=12, face="plain"))+ 
  theme(legend.position="bottom")+
  coord_cartesian(ylim=c())+
  theme(legend.position="right")+
  scale_y_continuous(expand = c(0, 0),limits=c(0, 1),breaks = seq(0, 1, by = 0.25))

graph_starch

#ggsave(file="FigureS1.png", width = 28, height = 20, units="cm", dpi=300)
#ggsave(file="FigureS1.pdf", width = 28, height = 20, units="cm", dpi=300)








#5.2 Recalculation of efficiencies with corrected starch 


Inputs_diet
Inputs_diet_corrected <- Inputs_diet

#Calculate the proportion of unconsumed starch
Separation_analysis <- subset(nutritional_overall, (part.x=="Diet" | part.x=="Residual_substrate"))
Separation_analysis <- Separation_analysis %>% select(1, 3,  12)
Separation_analysis <- spread(Separation_analysis, part.x, STARCH_overall)
Separation_analysis$proportion <- (Separation_analysis$Residual_substrate/Separation_analysis$Diet)

#Calculate the grams of starch in the diet corrected for the starch that was  found in the residues
Inputs_diet_corrected <- merge(Inputs_diet_corrected, Separation_analysis, by="replicate")
colnames(Inputs_diet_corrected)[14] <- "grams_Starch_residues"

Inputs_diet_corrected <- Inputs_diet_corrected %>% select (1, 2, 3, 5, 7 , 8, 12, 13, 14)

#Calculate the amount of carbon and energy contained in the starch found in the residues (see Supplementary methods 1.2)
#And substract this amount from the carbon and energy contained in the diet
Inputs_diet_corrected$gramsC_starchresidue <- (Inputs_diet_corrected$grams_Starch_residues *423)/1000 #423 g Carbon/1000 g STARCH
Inputs_diet_corrected$Kj_E_starchresidue <- (Inputs_diet_corrected$grams_Starch_residues *17.5) #17.5 kJ/g STARCH
Inputs_diet_corrected$C_input_corrected <- Inputs_diet_corrected$C_overall - Inputs_diet_corrected$gramsC_starchresidue
Inputs_diet_corrected$E_input_corrected <- Inputs_diet_corrected$E_overall - Inputs_diet_corrected$Kj_E_starchresidue


Inputs_diet_corrected <- Inputs_diet_corrected %>% select (1, 2, 5, 6, 10, 11, 12, 13)

#To build the balance again, we need to know the C and heat contained in gain larvae, residues and lost in the air (emissions and heat)
#and then remove the carbon and energy contained in the starch found in the residues from the total carbon and energy in the residues
residuesair <- Nutritional_outputs3
residuesair <- subset(residuesair, (part2!="Acid" & part2!="Condensed water"))
residuesair <- residuesair %>% select(1, 3, 7, 8)


x_residues <- subset(residuesair, part.x== "Residual_substrate")
x_residues[2] <- NULL
colnames(x_residues) [2] <- "C_residues"
colnames(x_residues) [3] <- "E_residues"


y_air <-  subset(residuesair, part.x== "Air")
y_air[2] <- NULL
colnames(y_air) [2] <- "C_air"
colnames(y_air) [3] <- "E_air"

z_larvae <- subset(residuesair, part.x== "Larvae_gain")
z_larvae[2] <- NULL
colnames(z_larvae) [2] <- "C_larvae"
colnames(z_larvae) [3] <- "E_larvae"


C_E_balance_corrected <- merge(Inputs_diet_corrected, x_residues, by="replicate")
C_E_balance_corrected$C_residues_corrected1 <- C_E_balance_corrected$C_residues - C_E_balance_corrected$gramsC_starchresidue
C_E_balance_corrected$E_residues_corrected1 <- C_E_balance_corrected$E_residues - C_E_balance_corrected$Kj_E_starchresidue

C_E_balance_corrected <- merge(C_E_balance_corrected, y_air, by="replicate")
C_E_balance_corrected <- merge(C_E_balance_corrected, z_larvae, by="replicate")


#Calculate the corrected balance (and also the original to compare)
#larvae
C_E_balance_corrected$C_larvae_corrected <- C_E_balance_corrected$C_larvae / C_E_balance_corrected$C_input_corrected*100
C_E_balance_corrected$E_larvae_corrected <- C_E_balance_corrected$E_larvae / C_E_balance_corrected$E_input_corrected*100
C_E_balance_corrected$C_larvae_original <- C_E_balance_corrected$C_larvae / C_E_balance_corrected$C_overall*100
C_E_balance_corrected$E_larvae_original <- C_E_balance_corrected$E_larvae / C_E_balance_corrected$E_overall*100

#residues
C_E_balance_corrected$C_residues_corrected <- C_E_balance_corrected$C_residues_corrected1 / C_E_balance_corrected$C_input_corrected*100
C_E_balance_corrected$E_residues_corrected <- C_E_balance_corrected$E_residues_corrected1 / C_E_balance_corrected$E_input_corrected*100
C_E_balance_corrected$C_residues_original <- C_E_balance_corrected$C_residues/ C_E_balance_corrected$C_overall*100
C_E_balance_corrected$E_residues_original <- C_E_balance_corrected$E_residues / C_E_balance_corrected$E_overall*100

#residues
C_E_balance_corrected$C_air_corrected <- C_E_balance_corrected$C_air / C_E_balance_corrected$C_input_corrected*100
C_E_balance_corrected$E_air_corrected <- C_E_balance_corrected$E_air / C_E_balance_corrected$E_input_corrected*100
C_E_balance_corrected$C_air_original <- C_E_balance_corrected$C_air / C_E_balance_corrected$C_overall*100
C_E_balance_corrected$E_air_original <- C_E_balance_corrected$E_air / C_E_balance_corrected$E_overall*100

C_E_balance_corrected <- C_E_balance_corrected %>% select (1, 17:28)
C_E_balance_corrected <- gather(C_E_balance_corrected, "part", "value", 2:13)

C_E_balance_corrected$part2 <- C_E_balance_corrected$part
C_E_balance_corrected <- C_E_balance_corrected %>% separate(part2, c("nutrient", "part", "status"), sep="_")


C_E_balance_corrected$replicate2 <- ifelse(C_E_balance_corrected$replicate=="Replicate8", "R1",
                                           ifelse(C_E_balance_corrected$replicate=="Replicate9", "R2",
                                                  ifelse(C_E_balance_corrected$replicate=="Replicate10", "R3",
                                                         ifelse(C_E_balance_corrected$replicate=="Replicate11", "R4",
                                                                ifelse(C_E_balance_corrected$replicate=="Replicate12", "R5",
                                                                       ifelse(C_E_balance_corrected$replicate=="Replicate13", "R6",
                                                                              ifelse(C_E_balance_corrected$replicate=="Replicate14", "R7",
                                                                                     ifelse(C_E_balance_corrected$replicate=="Replicate15", "R8",
                                                                                            ifelse(C_E_balance_corrected$replicate=="Replicate16", "R9",
                                                                                                   ifelse(C_E_balance_corrected$replicate=="Replicate19", "R10",
                                                                                                          ifelse(C_E_balance_corrected$replicate=="Replicate20", "R11", "AVG")))))))))))



#Given that the recovery rates for C and Energy were not 100%, 
#the balance needs to be corrected in a way that the sum of all outputs gives 100% (as did for the orignal value)

sum_correction <- ddply(C_E_balance_corrected, .(replicate, nutrient, status), summarize,
                        sum_all = sum(value))


C_E_balance_corrected$conca <- with(C_E_balance_corrected, paste0(replicate, "_", nutrient, "_", status))    

sum_correction$conca <- with(sum_correction, paste0(replicate, "_", nutrient, "_", status))  


C_E_balance_corrected <- merge(C_E_balance_corrected, sum_correction, by="conca")
C_E_balance_corrected$value2 <- (C_E_balance_corrected$value * 100)/C_E_balance_corrected$sum_all

#Figure

C_E_balance_corrected$part2=factor(C_E_balance_corrected$part2, levels=c("air", 
                                                                         "larvae", 
                                                                         "residues"))


C_E_balance_corrected$replicate2=factor(C_E_balance_corrected$replicate2, levels=c("AVG",
                                                                                   "R11",
                                                                                   "R10",
                                                                                   "R9",
                                                                                   "R8",
                                                                                   "R7",
                                                                                   "R6",
                                                                                   "R5",
                                                                                   "R4",
                                                                                   "R3",
                                                                                   "R2",
                                                                                   "R1"))






ggplot(C_E_balance_corrected, aes(y= value2, x=replicate2, fill=part), stat="identity")+ 
  geom_col() + 
  geom_text(aes(label = (paste0(round(value, digits = 1), "%")), group = part), position = position_stack(vjust = 0.5), size=2.5)+
  facet_wrap(status.x~nutrient.x, nrow =  2)+
  labs(y=expression("Percentage of total output"))+ 
  xlab("") +
  theme(strip.background = element_rect(colour="white", fill="white"))+
  theme(strip.text = element_text(size=10, face="bold", hjust=0))+ 
  theme(panel.grid.major  = element_line(colour = "white", size = 0.2))+ 
  theme(panel.grid.minor  = element_line(colour = "white", size = 0.5))+ 
  ggtitle("") + 
  theme(plot.title=element_text(size=13, face="bold", hjust = 1, vjust=0)) + 
  theme(plot.title = element_text(hjust = 0)) + 
  theme(axis.text.x = element_text(size = 10, face = "plain",  angle = 0, hjust = 0.5, vjust=1, colour="black", lineheight = 0)) + 
  theme(strip.text.y = element_text(angle = 0)) + 
  theme(strip.background=element_rect(fill="white")) + 
  guides(fill=guide_legend(title=" ")) +
  theme(axis.title.y = element_text(size=12, face="bold")) + 
  theme(axis.title.x  = element_text(size=14, face="bold"))+ 
  theme(legend.position="bottom")+
  coord_cartesian(ylim=c())+
  scale_fill_manual(values=c("#FFA500", "#8FBC8F", "#808000"))+
  theme(legend.position="right")+
  scale_y_continuous(expand = c(0, 0),limits=c(0, 150),breaks = seq(0, 100, by = 25))+
  coord_flip()


#Get averaged values:
average_c_e_efficiencies_corrected <- ddply(C_E_balance_corrected, .(part, status.x, nutrient.x), summarize,
                                            mean_C_corrected = mean(value2))

#The corrected values were reported.
average_c_e_efficiencies_corrected











#5.3 Microbial emissions - Figure S2
#See Figure 2 - Panel A for explanation

#Import dataset with the data from the pilot experiment
pilot_microbes <- read.csv("Emissions_figures2.csv")

#Explanation columns
#[1] "cel" - Refers to the respiration chamber in which the data was measured. In the experiments there were two climate respiration chambers: number 5 and number 6.
#[2] "B" - ID number of an experiment running simultaneously in two chambers. For example, replicates 9 and 10 were done simultaneously, one in chamber 5 and the other in chamber 6. Therefore, the B number is the same for both replicates.
#[3] "C" - Technical parameter of the climate respiration chamber (not used in the analysis)
#[4] "date" - Date in which the gas measurement took place.
#[5] "time" - Time in which the gas measurement took place.
#[6] "F" - Technical parameter of the climate respiration chamber (not used in the analysis)
#[7] "Heat" - Metabolic heat calculated by indirect calorimetry (KJ/Day)
#[8] "O2" - Oxigen consumption (L/day)
#[9] "CO2" - Carbon dioxide production (L/day)
#[10] "RQ" - Respiratory quotient (obtained by dividing CO2/O2)
#[11] "K" - Technical parameter of the climate respiration chamber (not used in the analysis)
#[12] "L" - Technical parameter of the climate respiration chamber (not used in the analysis)
#[13] "M" - Technical parameter of the climate respiration chamber (not used in the analysis)
#[14] "Barometric_pressure(mmHg)" - 	Barometric_pressure inside the chamber
#[15] "Temperature"	 - Temperature inside the chamber
#[16] "Humidity" - 	Humidity inside the chamber
#[17] "STDP" - 	Air ventilation (L/min) at standard pressure and temperature.
#[18] "CH4" - 	methane (L/day)
#[19] "Volume_corrected" - 	Volume of the chamber (L) corrected for pressure and temperature.
#[20] "day" - Obtained from the column "date". Shows the day number of the measurement (for example if date is 28/07/2018, day would be 28)
#[21] "month" - Obtained from the column "date". Shows the month number of the measurement (from 1 to 12)
#[22] "year" - 	Obtained from the column "date". Shows the year number of the measurement
#[23] "hour" - 	Obtained from the column "time". Shows the hour of day in 24:00 format in which the measurement was taken
#[24] "minute" - Obtained from the column "time". Shows the minutes of the hour in which the measurement was taken
#[25] "second"- Obtained from the column "time". Shows the seconds of the minute in which the measurement was taken	



#Prepare dataset for the Figure
pilot_microbes$daynumber <- ifelse(pilot_microbes$date == "01-05-2019", "Day1",
                                   ifelse(pilot_microbes$date == "02-05-2019", "Day2",
                                          ifelse(pilot_microbes$date == "03-05-2019", "Day3",
                                                 ifelse(pilot_microbes$date == "04-05-2019", "Day4",
                                                        ifelse(pilot_microbes$date == "05-05-2019", "Day5",
                                                               ifelse(pilot_microbes$date == "06-05-2019", "Day6",
                                                                      ifelse(pilot_microbes$date == "07-05-2019", "Day7",
                                                                             ifelse(pilot_microbes$date == "08-05-2019", "Day8",
                                                                                    ifelse(pilot_microbes$date == "09-05-2019", "Day9", "Day10")))))))))



#Add treatment names
pilot_microbes$treatment <- ifelse(pilot_microbes$cel == "5", "Larvae", "No larvae")

#Average per hour
pilot_microbes2 <- ddply(pilot_microbes, .(daynumber, treatment, hour), summarize, 
                         mean_CO2= mean(CO2, na.rm=TRUE), 
                         stdev_CO2= sd(CO2, na.rm=TRUE),
                         mean_CH4= mean(CH4, na.rm=TRUE), 
                         stdev_CH4= sd(CH4, na.rm=TRUE),
                         mean_RQ = mean(RQ, na.rm=TRUE),
                         stdev_RQ = sd(RQ, na.rm=TRUE),
                         mean_O2=mean(O2, na.rm=TRUE),
                         stdev_O2=sd(O2, na.rm=TRUE),
                         mean_heat= mean(Heat, na.rm=TRUE), 
                         stdev_heat= sd(Heat, na.rm=TRUE),
                         mean_temp= mean(Temperature, na.rm=TRUE), 
                         stdev_temp= sd(Temperature, na.rm=TRUE))


pilot_microbes2$hour <- as.numeric(as.character(pilot_microbes2$hour))
pilot_microbes2$day <- as.numeric(as.character(pilot_microbes2$day))


pilot_microbes2$daynumber =factor(pilot_microbes2$daynumber, levels=c("Day1",
                                                                      "Day2",
                                                                      "Day3",
                                                                      "Day4",
                                                                      "Day5",
                                                                      "Day6",
                                                                      "Day7",
                                                                      "Day8", 
                                                                      "Day9", 
                                                                      "Day10"))


pilot_microbes2$treatment2 <- ifelse(pilot_microbes2$treatment=="Larvae", "Treatment 1", "Treatment2")
pilot_microbes2$treatment = factor(pilot_microbes2$treatment, levels = c("Larvae", "No larvae"))
pilot_microbes2$treatment2 = factor(pilot_microbes2$treatment2, levels = c("Treatment 1", "Treatment2"))


#Figure S2 -Panel B
FS2_B <-  ggplot(data=pilot_microbes2, aes(x=hour, y=mean_CO2, group=treatment2, color=treatment2))+
  geom_line(size=0.5, aes(linetype=treatment2))+
  facet_wrap(~daynumber, ncol=10)+
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  theme_bw()+
  theme(axis.text.x = element_text(size=7, angle=0, vjust = 0.5),
        axis.text.y = element_text(size=7, angle=0),
        legend.title = element_blank(),
        strip.text = element_text(size = 6))+
  scale_y_continuous(name="CO2 (l/day)", expand = c(0,0)) +
  scale_x_continuous(name="Time of the day (hours)", expand = c(0, 0), breaks = c(0, 12, 0))+
  theme(panel.spacing = unit(0.1, "lines"))+
  ggtitle("B")+
  theme(legend.position = "")+
  guides(col=guide_legend(ncol=2))+
  scale_linetype_manual(values=c("solid", "dashed"))+
  scale_color_manual(values=c('#b36b00', '#008000'))

FS2_B


FS2_C <- ggplot(data=pilot_microbes2, aes(x=hour, y=mean_RQ, group=treatment2, color=treatment2))+
  geom_line(size=0.5, aes(linetype=treatment2))+
  facet_wrap(~daynumber, ncol=10)+
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  theme_bw()+
  theme(axis.text.x = element_text(size=7, angle=0, vjust = 0.5),
        axis.text.y = element_text(size=7, angle=0),
        legend.title = element_blank(),
        strip.text = element_text(size = 6))+
  scale_y_continuous(name="RQ", expand = c(0,0), limits = c(0.5, 1.5)) +
  scale_x_continuous(name="Time of the day (hours)", expand = c(0, 0), breaks = c(0, 12, 0))+
  theme(panel.spacing = unit(0.1, "lines"))+
  ggtitle("C")+
  theme(legend.position = "")+
  guides(col=guide_legend(ncol=2))+
  scale_linetype_manual(values=c("solid", "dashed"))+
  scale_color_manual(values=c('#b36b00', '#008000'))+
  geom_hline(yintercept=1, linetype="dashed", 
             color = "black", size=0.2)


FS2_C

#Combine two figures
grid.arrange(FS2_B, FS2_C, ncol=1)
FiguraSup2 <- arrangeGrob(FS2_B, FS2_C, ncol=1) #generates g
#ggsave(file="FiguraSup2bc.pdf", width = 10, height = 8, units="cm", dpi=300, FiguraSup2)
#ggsave(file="FiguraSup2bc.png", width = 10, height = 10, units="cm", dpi=300, FiguraSup2)


#Figure overall CO2 - Panel D
#Create dataset only with the data after day 6 (when the treatment started)
separate_emissions <- subset(pilot_microbes2, (daynumber=="Day6"|
                                                 daynumber=="Day7"|
                                                 daynumber=="Day8"|
                                                 daynumber=="Day9"|
                                                 daynumber=="Day10"))


separate_emissions$remove <- ifelse(separate_emissions$daynumber=="Day6" & separate_emissions$hour<15, "remove", "stay")
separate_emissions <- subset(separate_emissions, (remove=="stay"))

#Convert to grams and per hour
separate_emissions$CO2hourgrams <- (separate_emissions$mean_CO2 * 1.964732)/24
separate_average <- ddply(separate_emissions, .(treatment2), summarize, 
                          sum_CO2= sum(CO2hourgrams, na.rm=TRUE), 
                          stdev_CO2= sd(CO2hourgrams, na.rm=TRUE))

#Figure Panel D

ggplot(separate_average, aes(x = treatment2, y = sum_CO2, fill=treatment2))+
  geom_bar(stat="identity")+
  theme(text = element_text(size = 8),
        axis.title.x = element_blank(),
        legend.position = "none")+
  scale_y_continuous(name="CO2 (g)", expand=c(0,0))+
  theme(axis.line = element_line(size = 0.5, colour = "black"))+
  ggtitle("")+
  theme(axis.text.x = element_text(size = 8, face = "plain",  angle = 0, hjust = 0.5, vjust=0.5, 
                                   colour="black", lineheight = 0))+
  scale_fill_manual(values=c('#b36b00', '#008000'))

#ggsave(file="emissions_bar_pilot.pdf", width = 6, height = 8, units="cm", dpi=300) 










#5.4 Correlation CO2 and NH4 (Figure S4) and regression (TableS2)

#Collect data per replicate on characteristics of the residues
residues_nutritional_content <- subset(nutritional_results, (part=="diet"))
residues_nutritional_content[11] <- NULL

#Proportion of Starch
Starch_analysis

#Total Nitrogen from acid and condensed water
total_n

#Ammonia measured by sensor
ammonia_weight <- ddply(Ammonia_summary, .(replicate), summarize, 
                        total_nh3_grams = sum(weight_nh3_grams))


regression <- merge(residues_nutritional_content, Starch_analysis, by="replicate")
regression <- merge(regression, ammonia_weight, by = "replicate")
regression <- merge(regression, gasses_weight2, by="replicate")

#Add average size starter larvae
regression$starter <- c(7.83, 7.99, 7.99, 5.86, 5.86, 5.38, 5.38, 5.93, 7.83)

regression <- regression %>% dplyr::select (1, 3, 4, 5, 6, 7, 8, 9, 10, 11,14,15,17)
names(regression)[11] <- "Nair"
names(regression)[10] <- "prop_uneaten_starch"
names(regression)[12] <- "CO2"
regression$DM <- regression$DM * 100

regression <- merge(regression, total_n)
names(regression)[14] <- "total_N"

#Figure S4

ggscatter(regression, x = "Nair", y = "CO2", add = "reg.line", add.params = list(color = "black", fill = "lightgray"), # Customize reg. line
          conf.int = F) +
  stat_cor(
    aes(label = paste(..rr.label.., ..p.label.., sep = "~`,`~")),
    label.x = 0.15)+
  theme_classic()+
  theme(text = element_text(size = 12),
        legend.position = "none")+
  scale_x_continuous(name="Grams of NH3", limits = c(0, 0.35))+
  scale_y_continuous(name="Grams of CO2")+
  ggtitle("")+
  theme(axis.text.x = element_text(size = 8, face = "plain",  angle = 0, hjust = 0.5, vjust=0.5, 
                                   colour="black", lineheight = 0))+
  theme(axis.text.x = element_text(size=10, angle=0, vjust = 0.5),
        axis.text.y = element_text(size=10, angle=0),
        legend.title = element_blank())



#Regression

fit <- lm(Nair ~ DM  + N +  E + prop_uneaten_starch + starter + CO2, data=regression)

summary(fit)

#Table S2
tidy(fit)
regression_df <- tidy(fit)

#write.csv(regression_df, file = "TableS2.csv", row.names = F)









#5.5 Parameters (larvae, water, residues, size, etc)

#5.5.1 Average size of starters and 14-days old larvae
starter_larvae <- read.csv("starter_larvae.csv")
adult_larvae <- read.csv("adult_larvae.csv")

#Column explanation for both datasets
#[1]Replicate - Replicate code (Replicate8, Replicate9, etc)
#[2]grams_fifty_larvae -> weight in grams of 50 starter larvae
#[3]replicate -> Another code of replicate (R1,R2,R3, etc)

adult_larvae <- read.csv("adult_larvae.csv")
#Column explanation for both datasets
#[1]Replicate - Replicate code (Replicate8, Replicate9, etc)
#[2]grams_fifty_larvae -> weight in grams of 50 14-days old larvae
#[3]replicate -> Another code of replicate (R1,R2,R3, etc)


#Calculate the average weight of starter and 14-days old larvae
starter_larvae$weight_mg <- (starter_larvae$grams_fifty_larvae/50)*1000
adult_larvae$weight_mg <- (adult_larvae$gramsfifty/50)*1000
starter_summary <- ddply(starter_larvae, .(replicate), summarize,
                         mean = mean(weight_mg),
                         sderror= std.error(weight_mg))

adult_summary <- ddply(adult_larvae, .(replicate2), summarize,
                       mean = mean(weight_mg),
                       sderror= std.error(weight_mg))

starter_size_avg <- ddply(starter_larvae, . (), summarize,
                          mean=mean(weight_mg),
                          sd = sd(weight_mg))


starter_size_avg$Variable <- "Starter individual weight (mg)"
starter_size_avg$Value <- with(starter_size_avg, paste0(round(mean, digits=0), "", round(sd, digits = 1)))
starter_size_avg <- starter_size_avg %>% select(4, 5)
names(starter_size_avg)[2] <- "Mean  std.dev"

adult_size_avg <- ddply(adult_larvae, . (), summarize,
                        mean=mean(weight_mg),
                        sd = sd(weight_mg))


adult_size_avg$Variable <- "Adult larvae individual weight (mg)"
adult_size_avg$Value <- with(adult_size_avg, paste0(round(mean, digits=0), "", round(sd, digits = 1)))
adult_size_avg <- adult_size_avg %>% select(4, 5)
names(adult_size_avg)[2] <- "Mean  std.dev"



#5.5.2 Material degradation

#residues dry matter
Mat_degradation_dry <- Nutritional_outputs3 %>% select(1, 2, 3, 5)
Mat_degradation_dry <- subset(Mat_degradation_dry, (part.x=="Residual_substrate"))
Mat_degradation_dry <- Mat_degradation_dry %>% select(1, 4)
names(Mat_degradation_dry)[2] <- "residues_dry"

#residues fresh
Mat_degradation_fresh <- subset(fresh_biomass_replicate, (part=="crust" | part=="frass"))
Mat_degradation_fresh <- Mat_degradation_fresh %>% select(1, 2, 3)
Mat_degradation_fresh <- ddply(Mat_degradation_fresh, .(replicate), summarize,
                               residues_fresh = sum(freshweight_grams))


#Input diet
Diet_degradation <- Inputs_diet %>% select(1, 5)
names(Diet_degradation)[2] <- "diet_dry"
Diet_degradation$diet_fresh <- 12000


#Material degradation ->  100-(DM_RESIDUES / DM DIET) X 100
degradation <- merge(Mat_degradation_dry, Diet_degradation)

degradation$reduction_percentage <- (100 - ((degradation$residues_dry/degradation$diet_dry)*100))

degradation_summary <- ddply(degradation, .(), summarize,
                             material_reduction_mean = mean(reduction_percentage),
                             material_reduction_sd = sd(reduction_percentage))


degradation_summary$export <- with(degradation_summary, paste0(round(material_reduction_mean, digits=0), "", round(material_reduction_sd, digits = 1)))
degradation_summary$variable <- "Mass reduction of initial material (%)"
degradation_summary <- degradation_summary %>% select (5,4)

#5.5.3. Water balance
#starter input
starters_dry <- Input_starter %>% select(1, 5)
names(starters_dry) [2] <- "starters_dry"

starters_fresh <- subset(fresh_biomass_replicate, (part=="starter"))
starters_fresh <- starters_fresh %>% select (1, 3)
names(starters_fresh) [2] <- "starters_fresh" 

#mature larvae
Larvae_dry <- Nutritional_outputs2 %>% select(1, 2, 3, 5)
Larvae_dry<- subset(Larvae_dry, (part.x=="Larvae"))
Larvae_dry <- Larvae_dry %>% select(1, 4)
names(Larvae_dry)[2] <- "larvae_dry"

larvae_fresh <- subset(fresh_biomass_replicate, (part=="larvae"))
larvae_fresh <- larvae_fresh %>% select (1, 3)
names(larvae_fresh) [2] <- "larvae_fresh" 

#Residues
water_residues <- merge(Mat_degradation_dry, Mat_degradation_fresh)
water_residues$residues_water_grams <- water_residues$residues_fresh - water_residues$residues_dry
water_residues <- water_residues %>% select(1, 4)


#Starters
water_starters <- merge(starters_fresh, starters_dry)
water_starters$starters_water_grams <- water_starters$starters_fresh - water_starters$starters_dry
water_starters <- water_starters%>% select(1, 4)

#Diet

water_diet <- Diet_degradation
water_diet$diet_water_grams <- water_diet$diet_fresh - water_diet$diet_dry
water_diet <- water_diet %>% select(1, 4)
#Mature larvae

water_larvae <- merge(Larvae_dry, larvae_fresh)
water_larvae$larvae_water_grams <- water_larvae$larvae_fresh - water_larvae$larvae_dry
water_larvae <- water_larvae %>% select(1, 4)


#total water balance

total_water <- merge(water_diet, water_starters)
total_water <- merge(total_water, water_larvae)
total_water <- merge(total_water, water_residues)

total_water$larvae_gain <- ((total_water$larvae_water_grams-total_water$starters_water_grams)/total_water$diet_water_grams)*100
total_water$larvae_nogain <- ((total_water$larvae_water_grams)/total_water$diet_water_grams)*100

total_water$residues <- (total_water$residues_water_grams/total_water$diet_water_grams)*100

#summary
summary_water_balance <- gather(total_water, "variable", "value", 2:8)

summary_water_balance<- ddply(summary_water_balance, .(variable), summarize,
                              mean = mean(value),
                              sd = sd(value))

summary_water_balance <- summary_water_balance[c(1,7,4,6,2,3,5), ]
summary_water_balance$export <- with(summary_water_balance, paste0(round(mean, digits=0), "", round(sd, digits = 1)))
summary_water_balance <- summary_water_balance %>% select(1, 4)


#5.5.4 Formatting for Suplementary Table S4 
newtable <- rbind(summary_water_balance, degradation_summary)

newtable$variable <- ifelse(newtable$variable=="diet_water_grams", "Water in substrate (g)", newtable$variable)
newtable$variable <- ifelse(newtable$variable=="starters_water_grams", "Water in starters (g)", newtable$variable)
newtable$variable <- ifelse(newtable$variable=="larvae_water_grams", "Water in mature larvae (g)", newtable$variable)
newtable$variable <- ifelse(newtable$variable=="residues_water_grams", "Water in residues (g)", newtable$variable)
newtable$variable <- ifelse(newtable$variable=="larvae_gain", "Water retention in larvae1 (%)", newtable$variable)
newtable$variable <- ifelse(newtable$variable=="larvae_nogain", "Water retention in larvae2 (%)", newtable$variable)
newtable$variable <- ifelse(newtable$variable=="residues", "Water retention in residues (%)", newtable$variable)


names(newtable)[1] <- "Variable"
names(newtable)[2] <- "Mean  std.dev"

newtable <- rbind(newtable, starter_size_avg, adult_size_avg)
newtable <- newtable[c(9, 10, 8, 5, 6, 7, 1, 2, 3, 4, 5 ), ]
newtable

#write.csv(newtable, file="TableS4.csv", row.names=FALSE)

